@@ -18,7 +18,7 @@ func (g *cmdGlobal) cmpClusterGroupNames(toComplete string) ([]string, cobra.She
 	var results []string
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -43,7 +43,7 @@ func (g *cmdGlobal) cmpClusterGroups(toComplete string) ([]string, cobra.ShellCo
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -84,7 +84,7 @@ func (g *cmdGlobal) cmpClusterGroups(toComplete string) ([]string, cobra.ShellCo
 
 func (g *cmdGlobal) cmpClusterMemberConfigs(memberName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(memberName)
+	resources, err := g.parseServers(memberName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -112,7 +112,7 @@ func (g *cmdGlobal) cmpClusterMemberConfigs(memberName string) ([]string, cobra.
 
 func (g *cmdGlobal) cmpClusterMemberRoles(memberName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(memberName)
+	resources, err := g.parseServers(memberName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -137,7 +137,7 @@ func (g *cmdGlobal) cmpClusterMembers(toComplete string) ([]string, cobra.ShellC
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -246,7 +246,7 @@ func (g *cmdGlobal) cmpInstanceAllKeys() ([]string, cobra.ShellCompDirective) {
 
 func (g *cmdGlobal) cmpInstanceConfigTemplates(instanceName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(instanceName)
+	resources, err := g.parseServers(instanceName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -270,7 +270,7 @@ func (g *cmdGlobal) cmpInstanceConfigTemplates(instanceName string) ([]string, c
 
 func (g *cmdGlobal) cmpInstanceDeviceNames(instanceName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(instanceName)
+	resources, err := g.parseServers(instanceName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -292,7 +292,7 @@ func (g *cmdGlobal) cmpInstanceDeviceNames(instanceName string) ([]string, cobra
 }
 
 func (g *cmdGlobal) cmpInstanceSnapshots(instanceName string) ([]string, cobra.ShellCompDirective) {
-	resources, err := g.ParseServers(instanceName)
+	resources, err := g.parseServers(instanceName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -312,7 +312,7 @@ func (g *cmdGlobal) cmpInstances(toComplete string) ([]string, cobra.ShellCompDi
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -348,7 +348,7 @@ func (g *cmdGlobal) cmpInstancesAndSnapshots(toComplete string) ([]string, cobra
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -387,7 +387,7 @@ func (g *cmdGlobal) cmpInstancesAndSnapshots(toComplete string) ([]string, cobra
 func (g *cmdGlobal) cmpInstanceNamesFromRemote(toComplete string) ([]string, cobra.ShellCompDirective) {
 	results := []string{}
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -403,7 +403,7 @@ func (g *cmdGlobal) cmpInstanceNamesFromRemote(toComplete string) ([]string, cob
 
 func (g *cmdGlobal) cmpNetworkACLConfigs(aclName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(aclName)
+	resources, err := g.parseServers(aclName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -428,7 +428,7 @@ func (g *cmdGlobal) cmpNetworkACLs(toComplete string) ([]string, cobra.ShellComp
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -475,7 +475,7 @@ func (g *cmdGlobal) cmpNetworkACLRuleProperties() ([]string, cobra.ShellCompDire
 
 func (g *cmdGlobal) cmpNetworkForwardConfigs(networkName string, listenAddress string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(networkName)
+	resources, err := g.parseServers(networkName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -497,10 +497,9 @@ func (g *cmdGlobal) cmpNetworkForwardConfigs(networkName string, listenAddress s
 }
 
 func (g *cmdGlobal) cmpNetworkForwards(networkName string) ([]string, cobra.ShellCompDirective) {
-	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(networkName)
+	resources, _ := g.parseServers(networkName)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -517,10 +516,9 @@ func (g *cmdGlobal) cmpNetworkForwards(networkName string) ([]string, cobra.Shel
 }
 
 func (g *cmdGlobal) cmpNetworkLoadBalancers(networkName string) ([]string, cobra.ShellCompDirective) {
-	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(networkName)
+	resources, _ := g.parseServers(networkName)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -540,7 +538,7 @@ func (g *cmdGlobal) cmpNetworkPeerConfigs(networkName string, peerName string) (
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(networkName)
+	resources, _ := g.parseServers(networkName)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -561,10 +559,9 @@ func (g *cmdGlobal) cmpNetworkPeerConfigs(networkName string, peerName string) (
 }
 
 func (g *cmdGlobal) cmpNetworkPeers(networkName string) ([]string, cobra.ShellCompDirective) {
-	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(networkName)
+	resources, _ := g.parseServers(networkName)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -584,7 +581,7 @@ func (g *cmdGlobal) cmpNetworks(toComplete string) ([]string, cobra.ShellCompDir
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -618,7 +615,7 @@ func (g *cmdGlobal) cmpNetworks(toComplete string) ([]string, cobra.ShellCompDir
 
 func (g *cmdGlobal) cmpNetworkConfigs(networkName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(networkName)
+	resources, err := g.parseServers(networkName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -641,7 +638,7 @@ func (g *cmdGlobal) cmpNetworkConfigs(networkName string) ([]string, cobra.Shell
 
 func (g *cmdGlobal) cmpNetworkInstances(networkName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(networkName)
+	resources, err := g.parseServers(networkName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -669,7 +666,7 @@ func (g *cmdGlobal) cmpNetworkInstances(networkName string) ([]string, cobra.She
 
 func (g *cmdGlobal) cmpNetworkProfiles(networkName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(networkName)
+	resources, err := g.parseServers(networkName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -697,7 +694,7 @@ func (g *cmdGlobal) cmpNetworkProfiles(networkName string) ([]string, cobra.Shel
 
 func (g *cmdGlobal) cmpNetworkZoneConfigs(zoneName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(zoneName)
+	resources, err := g.parseServers(zoneName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -722,7 +719,7 @@ func (g *cmdGlobal) cmpNetworkZoneRecordConfigs(zoneName string, recordName stri
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(zoneName)
+	resources, _ := g.parseServers(zoneName)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -743,10 +740,9 @@ func (g *cmdGlobal) cmpNetworkZoneRecordConfigs(zoneName string, recordName stri
 }
 
 func (g *cmdGlobal) cmpNetworkZoneRecords(zoneName string) ([]string, cobra.ShellCompDirective) {
-	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(zoneName)
+	resources, _ := g.parseServers(zoneName)
 
 	if len(resources) <= 0 {
 		return nil, cobra.ShellCompDirectiveError
@@ -766,7 +762,7 @@ func (g *cmdGlobal) cmpNetworkZones(toComplete string) ([]string, cobra.ShellCom
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -799,7 +795,7 @@ func (g *cmdGlobal) cmpNetworkZones(toComplete string) ([]string, cobra.ShellCom
 }
 
 func (g *cmdGlobal) cmpProfileConfigs(profileName string) ([]string, cobra.ShellCompDirective) {
-	resources, err := g.ParseServers(profileName)
+	resources, err := g.parseServers(profileName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -822,7 +818,7 @@ func (g *cmdGlobal) cmpProfileConfigs(profileName string) ([]string, cobra.Shell
 
 func (g *cmdGlobal) cmpProfileDeviceNames(instanceName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(instanceName)
+	resources, err := g.parseServers(instanceName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -846,7 +842,7 @@ func (g *cmdGlobal) cmpProfileDeviceNames(instanceName string) ([]string, cobra.
 func (g *cmdGlobal) cmpProfileNamesFromRemote(toComplete string) ([]string, cobra.ShellCompDirective) {
 	results := []string{}
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -862,7 +858,7 @@ func (g *cmdGlobal) cmpProfiles(toComplete string, includeRemotes bool) ([]strin
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -892,7 +888,7 @@ func (g *cmdGlobal) cmpProfiles(toComplete string, includeRemotes bool) ([]strin
 }
 
 func (g *cmdGlobal) cmpProjectConfigs(projectName string) ([]string, cobra.ShellCompDirective) {
-	resources, err := g.ParseServers(projectName)
+	resources, err := g.parseServers(projectName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -917,7 +913,7 @@ func (g *cmdGlobal) cmpProjects(toComplete string) ([]string, cobra.ShellCompDir
 	results := []string{}
 	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -983,7 +979,7 @@ func (g *cmdGlobal) cmpRemoteNames() ([]string, cobra.ShellCompDirective) {
 
 func (g *cmdGlobal) cmpStoragePoolConfigs(poolName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(poolName)
+	resources, err := g.parseServers(poolName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -1044,7 +1040,7 @@ func (g *cmdGlobal) cmpStoragePoolWithVolume(toComplete string) ([]string, cobra
 func (g *cmdGlobal) cmpStoragePools(toComplete string) ([]string, cobra.ShellCompDirective) {
 	results := []string{}
 
-	resources, _ := g.ParseServers(toComplete)
+	resources, _ := g.parseServers(toComplete)
 
 	if len(resources) > 0 {
 		resource := resources[0]
@@ -1074,7 +1070,7 @@ func (g *cmdGlobal) cmpStoragePools(toComplete string) ([]string, cobra.ShellCom
 
 func (g *cmdGlobal) cmpStoragePoolVolumeConfigs(poolName string, volumeName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(poolName)
+	resources, err := g.parseServers(poolName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -1104,7 +1100,7 @@ func (g *cmdGlobal) cmpStoragePoolVolumeConfigs(poolName string, volumeName stri
 
 func (g *cmdGlobal) cmpStoragePoolVolumeInstances(poolName string, volumeName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(poolName)
+	resources, err := g.parseServers(poolName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -1139,7 +1135,7 @@ func (g *cmdGlobal) cmpStoragePoolVolumeInstances(poolName string, volumeName st
 
 func (g *cmdGlobal) cmpStoragePoolVolumeProfiles(poolName string, volumeName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(poolName)
+	resources, err := g.parseServers(poolName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -1174,7 +1170,7 @@ func (g *cmdGlobal) cmpStoragePoolVolumeProfiles(poolName string, volumeName str
 
 func (g *cmdGlobal) cmpStoragePoolVolumeSnapshots(poolName string, volumeName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(poolName)
+	resources, err := g.parseServers(poolName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
@@ -1199,7 +1195,7 @@ func (g *cmdGlobal) cmpStoragePoolVolumeSnapshots(poolName string, volumeName st
 
 func (g *cmdGlobal) cmpStoragePoolVolumes(poolName string) ([]string, cobra.ShellCompDirective) {
 	// Parse remote
-	resources, err := g.ParseServers(poolName)
+	resources, err := g.parseServers(poolName)
 	if err != nil || len(resources) == 0 {
 		return nil, cobra.ShellCompDirectiveError
 	}
