@@ -1,6 +1,7 @@
 package main
 
 import (
+	"errors"
 	"fmt"
 	"io"
 	"net"
@@ -9,9 +10,11 @@ import (
 	"runtime"
 	"slices"
 	"strconv"
+	"strings"
 	"sync"
 
 	"github.com/gorilla/websocket"
+	"github.com/kballard/go-shellquote"
 	"github.com/spf13/cobra"
 
 	incus "github.com/lxc/incus/v6/client"
@@ -31,6 +34,7 @@ type cmdConsole struct {
 	flagType    string
 }
 
+// Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdConsole) Command() *cobra.Command {
 	cmd := &cobra.Command{}
 	cmd.Use = usage("console", i18n.G("[<remote>:]<instance>"))
@@ -44,9 +48,9 @@ as well as retrieve past log entries from it.`))
 	cmd.RunE = c.Run
 	cmd.Flags().BoolVarP(&c.flagForce, "force", "f", false, i18n.G("Forces a connection to the console, even if there is already an active session"))
 	cmd.Flags().BoolVar(&c.flagShowLog, "show-log", false, i18n.G("Retrieve the instance's console log"))
-	cmd.Flags().StringVarP(&c.flagType, "type", "t", "console", i18n.G("Type of connection to establish: 'console' for serial console, 'vga' for SPICE graphical output")+"``")
+	cmd.Flags().StringVarP(&c.flagType, "type", "t", c.global.defaultConsoleType(), i18n.G("Type of connection to establish: 'console' for serial console, 'vga' for SPICE graphical output")+"``")
 
-	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+	cmd.ValidArgsFunction = func(_ *cobra.Command, _ []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return c.global.cmpInstances(toComplete)
 	}
 
@@ -101,11 +105,12 @@ func (er stdinMirror) Read(p []byte) (int, error) {
 	return n, err
 }
 
+// Run runs the actual command logic.
 func (c *cmdConsole) Run(cmd *cobra.Command, args []string) error {
 	conf := c.global.conf
 
 	// Quick checks.
-	exit, err := c.global.CheckArgs(cmd, args, 1, 1)
+	exit, err := c.global.checkArgs(cmd, args, 1, 1)
 	if exit {
 		return err
 	}
@@ -133,7 +138,7 @@ func (c *cmdConsole) console(d incus.InstanceServer, name string) error {
 	// Show the current log if requested.
 	if c.flagShowLog {
 		if c.flagType != "console" {
-			return fmt.Errorf(i18n.G("The --show-log flag is only supported for by 'console' output type"))
+			return errors.New(i18n.G("The --show-log flag is only supported for by 'console' output type"))
 		}
 
 		console := &incus.InstanceConsoleLogArgs{}
@@ -200,8 +205,10 @@ func (c *cmdConsole) text(d incus.InstanceServer, name string) error {
 	defer close(sendDisconnect)
 
 	consoleArgs := incus.InstanceConsoleArgs{
-		Terminal: &readWriteCloser{stdinMirror{os.Stdin,
-			manualDisconnect, new(bool)}, os.Stdout},
+		Terminal: &readWriteCloser{stdinMirror{
+			os.Stdin,
+			manualDisconnect, new(bool),
+		}, os.Stdout},
 		Control:           handler,
 		ConsoleDisconnect: consoleDisconnect,
 	}
@@ -215,7 +222,7 @@ func (c *cmdConsole) text(d incus.InstanceServer, name string) error {
 		close(consoleDisconnect)
 
 		// Make sure we leave the user back to a clean prompt.
-		fmt.Printf("\r\n")
+		fmt.Print("\r\n")
 	}()
 
 	// Attach to the instance console
@@ -224,7 +231,7 @@ func (c *cmdConsole) text(d incus.InstanceServer, name string) error {
 		return err
 	}
 
-	fmt.Printf(i18n.G("To detach from the console, press: <ctrl>+a q") + "\n\r")
+	fmt.Print(i18n.G("To detach from the console, press: <ctrl>+a q") + "\n\r")
 
 	// Wait for the operation to complete
 	err = op.Wait()
@@ -267,7 +274,7 @@ func (c *cmdConsole) vga(d incus.InstanceServer, name string) error {
 	if runtime.GOOS != "windows" {
 		// Create a temporary unix socket mirroring the instance's spice socket.
 		if !util.PathExists(conf.ConfigPath("sockets")) {
-			err := os.MkdirAll(conf.ConfigPath("sockets"), 0700)
+			err := os.MkdirAll(conf.ConfigPath("sockets"), 0o700)
 			if err != nil {
 				return err
 			}
@@ -301,7 +308,11 @@ func (c *cmdConsole) vga(d incus.InstanceServer, name string) error {
 			return err
 		}
 
-		addr := listener.Addr().(*net.TCPAddr)
+		addr, ok := listener.Addr().(*net.TCPAddr)
+		if !ok {
+			return errors.New("Bad TCP listener")
+		}
+
 		socket = fmt.Sprintf("spice://127.0.0.1:%d", addr.Port)
 	}
 
@@ -349,13 +360,25 @@ func (c *cmdConsole) vga(d incus.InstanceServer, name string) error {
 		}
 	}()
 
+	// Get the preferred SPICE command.
+	preferredSpiceCmd := c.global.defaultConsoleSpiceCommand()
+
 	// Use either spicy or remote-viewer if available.
 	remoteViewer := c.findCommand("remote-viewer")
 	spicy := c.findCommand("spicy")
 
-	if remoteViewer != "" || spicy != "" {
+	if preferredSpiceCmd != "" || remoteViewer != "" || spicy != "" {
 		var cmd *exec.Cmd
-		if remoteViewer != "" {
+
+		if preferredSpiceCmd != "" {
+			// preferredSpiceCmd takes a string where the SOCKET keyword is replaced with the path to the SPICE socket.
+			cmdSlice, err := shellquote.Split(strings.ReplaceAll(preferredSpiceCmd, "SOCKET", socket))
+			if err != nil {
+				return err
+			}
+
+			cmd = exec.Command(cmdSlice[0], cmdSlice[1:]...)
+		} else if remoteViewer != "" {
 			cmd = exec.Command(remoteViewer, socket)
 		} else {
 			cmd = exec.Command(spicy, fmt.Sprintf("--uri=%s", socket))
