@@ -62,18 +62,18 @@ func evacuateClusterSetState(s *state.State, name string, newState int) error {
 		}
 
 		if node.State == db.ClusterMemberStatePending {
-			return fmt.Errorf("Cannot evacuate or restore a pending cluster member")
+			return errors.New("Cannot evacuate or restore a pending cluster member")
 		}
 
 		// Do nothing if the node is already in expected state.
 		if node.State == newState {
 			if newState == db.ClusterMemberStateEvacuated {
-				return fmt.Errorf("Cluster member is already evacuated")
+				return errors.New("Cluster member is already evacuated")
 			} else if newState == db.ClusterMemberStateCreated {
-				return fmt.Errorf("Cluster member is already restored")
+				return errors.New("Cluster member is already restored")
 			}
 
-			return fmt.Errorf("Cluster member is already in requested state")
+			return errors.New("Cluster member is already in requested state")
 		}
 
 		// Set node status to requested value.
@@ -161,7 +161,7 @@ func evacuateClusterMember(ctx context.Context, s *state.State, op *operations.O
 
 func evacuateInstances(ctx context.Context, opts evacuateOpts) error {
 	if opts.migrateInstance == nil {
-		return fmt.Errorf("Missing migration callback function")
+		return errors.New("Missing migration callback function")
 	}
 
 	// Limit the number of concurrent evacuations to run at the same time
@@ -362,7 +362,7 @@ func restoreClusterMember(d *Daemon, r *http.Request) response.Response {
 		// Limit the number of concurrent migrations to run at the same time
 		numParallelMigrations := max(runtime.NumCPU()/16, 1)
 
-		group := new(errgroup.Group)
+		group := &errgroup.Group{}
 		group.SetLimit(numParallelMigrations)
 
 		// Migrate back the remote instances.
@@ -619,7 +619,7 @@ func evacuateClusterSelectTarget(ctx context.Context, s *state.State, inst insta
 	}
 
 	if targetMemberInfo == nil {
-		return nil, nil, fmt.Errorf("Couldn't find a cluster member for the instance")
+		return nil, nil, errors.New("Couldn't find a cluster member for the instance")
 	}
 
 	return sourceMemberInfo, targetMemberInfo, nil
@@ -793,7 +793,7 @@ func healClusterMember(d *Daemon, op *operations.Operation, name string) error {
 
 	// Attempt up to 5 evacuations.
 	var err error
-	for i := 0; i < 5; i++ {
+	for range 5 {
 		err = evacuateClusterMember(context.Background(), s, op, name, "heal", nil, migrateFunc)
 		if err == nil {
 			s.Events.SendLifecycle(api.ProjectDefaultName, lifecycle.ClusterMemberHealed.Event(name, op.Requestor(), nil))
