@@ -5,6 +5,7 @@ import (
 	"context"
 	"database/sql"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"net/http"
@@ -232,7 +233,7 @@ func internalCreateWarning(d *Daemon, r *http.Request) response.Response {
 	// Check if the entity exists, and fail if it doesn't.
 	_, ok := cluster.EntityNames[req.EntityTypeCode]
 	if req.EntityTypeCode != -1 && !ok {
-		return response.SmartError(fmt.Errorf("Invalid entity type"))
+		return response.SmartError(errors.New("Invalid entity type"))
 	}
 
 	err = d.State().DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
@@ -264,7 +265,7 @@ func internalOptimizeImage(d *Daemon, r *http.Request) response.Response {
 	return response.EmptySyncResponse
 }
 
-func internalRefreshImage(d *Daemon, r *http.Request) response.Response {
+func internalRefreshImage(d *Daemon, _ *http.Request) response.Response {
 	s := d.State()
 
 	err := autoUpdateImages(s.ShutdownCtx, s)
@@ -275,15 +276,15 @@ func internalRefreshImage(d *Daemon, r *http.Request) response.Response {
 	return response.EmptySyncResponse
 }
 
-func internalWaitReady(d *Daemon, r *http.Request) response.Response {
+func internalWaitReady(d *Daemon, _ *http.Request) response.Response {
 	// Check that we're not shutting down.
 	isClosing := d.State().ShutdownCtx.Err() != nil
 	if isClosing {
-		return response.Unavailable(fmt.Errorf("Daemon is shutting down"))
+		return response.Unavailable(errors.New("Daemon is shutting down"))
 	}
 
 	if d.waitReady.Err() == nil {
-		return response.Unavailable(fmt.Errorf("Daemon not ready yet"))
+		return response.Unavailable(errors.New("Daemon not ready yet"))
 	}
 
 	return response.EmptySyncResponse
@@ -320,7 +321,7 @@ func internalShutdown(d *Daemon, r *http.Request) response.Response {
 		if ok {
 			f.Flush()
 		} else {
-			return fmt.Errorf("http.ResponseWriter is not type http.Flusher")
+			return errors.New("http.ResponseWriter is not type http.Flusher")
 		}
 
 		// Send result of d.Stop() to cmdDaemon so that process stops with correct exit code from Stop().
@@ -369,7 +370,7 @@ func internalContainerHookLoadFromReference(s *state.State, r *http.Request) (in
 	}
 
 	if inst.Type() != instancetype.Container {
-		return nil, fmt.Errorf("Instance is not container type")
+		return nil, errors.New("Instance is not container type")
 	}
 
 	return inst, nil
@@ -462,7 +463,7 @@ func internalVirtualMachineOnResize(d *Daemon, r *http.Request) response.Respons
 	// Get the devices list.
 	devices := request.QueryParam(r, "devices")
 	if devices == "" {
-		return response.BadRequest(fmt.Errorf("Resize hook requires a list of devices"))
+		return response.BadRequest(errors.New("Resize hook requires a list of devices"))
 	}
 
 	// Load by ID.
@@ -507,7 +508,7 @@ func internalSQLGet(d *Daemon, r *http.Request) response.Response {
 	database := r.FormValue("database")
 
 	if !slices.Contains([]string{"local", "global"}, database) {
-		return response.BadRequest(fmt.Errorf("Invalid database"))
+		return response.BadRequest(errors.New("Invalid database"))
 	}
 
 	schemaFormValue := r.FormValue("schema")
@@ -550,11 +551,11 @@ func internalSQLPost(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if !slices.Contains([]string{"local", "global"}, req.Database) {
-		return response.BadRequest(fmt.Errorf("Invalid database"))
+		return response.BadRequest(errors.New("Invalid database"))
 	}
 
 	if req.Query == "" {
-		return response.BadRequest(fmt.Errorf("No query provided"))
+		return response.BadRequest(errors.New("No query provided"))
 	}
 
 	var db *sql.DB
@@ -672,7 +673,7 @@ func internalSQLExec(tx *sql.Tx, query string, result *internalSQL.SQLResult) er
 // It expects the instance volume to be mounted so that the backup.yaml file is readable.
 func internalImportFromBackup(ctx context.Context, s *state.State, projectName string, instName string, allowNameOverride bool) error {
 	if instName == "" {
-		return fmt.Errorf("The name of the instance is required")
+		return errors.New("The name of the instance is required")
 	}
 
 	storagePoolsPath := internalUtil.VarPath("storage-pools")
@@ -743,7 +744,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 		return err
 	}
 
-	if allowNameOverride && instName != "" {
+	if allowNameOverride {
 		backupConf.Container.Name = instName
 	}
 
@@ -753,7 +754,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 
 	if backupConf.Pool == nil {
 		// We don't know what kind of storage type the pool is.
-		return fmt.Errorf("No storage pool struct in the backup file found. The storage pool needs to be recovered manually")
+		return errors.New("No storage pool struct in the backup file found. The storage pool needs to be recovered manually")
 	}
 
 	// Try to retrieve the storage pool the instance supposedly lives on.
@@ -820,7 +821,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 	}
 
 	if backupConf.Volume == nil {
-		return fmt.Errorf(`No storage volume struct in the backup file found. The storage volume needs to be recovered manually`)
+		return errors.New(`No storage volume struct in the backup file found. The storage volume needs to be recovered manually`)
 	}
 
 	var profiles []api.Profile
@@ -836,20 +837,20 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 
 	// Add root device if needed.
 	if backupConf.Container.Devices == nil {
-		backupConf.Container.Devices = make(map[string]map[string]string, 0)
+		backupConf.Container.Devices = make(map[string]map[string]string)
 	}
 
 	if backupConf.Container.ExpandedDevices == nil {
-		backupConf.Container.ExpandedDevices = make(map[string]map[string]string, 0)
+		backupConf.Container.ExpandedDevices = make(map[string]map[string]string)
 	}
 
 	internalImportRootDevicePopulate(instancePoolName, backupConf.Container.Devices, backupConf.Container.ExpandedDevices, profiles)
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	if backupConf.Container == nil {
-		return fmt.Errorf("No instance config in backup config")
+		return errors.New("No instance config in backup config")
 	}
 
 	instDBArgs, err := backup.ConfigToInstanceDBArgs(s, backupConf, projectName, true)
@@ -862,7 +863,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 		return fmt.Errorf("Failed creating instance record: %w", err)
 	}
 
-	revert.Add(cleanup)
+	reverter.Add(cleanup)
 	defer instOp.Done(err)
 
 	instancePath := storagePools.InstancePath(instanceType, projectName, backupConf.Container.Name, false)
@@ -907,32 +908,14 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 			return err
 		}
 
-		// If a storage volume entry exists only proceed if force was specified.
+		// If the storage volume entry does already exist we error here
 		if dbVolume != nil {
 			return fmt.Errorf(`Storage volume for snapshot %q already exists in the database`, snapInstName)
 		}
 
-		if snapErr == nil {
-			err := s.DB.Cluster.Transaction(ctx, func(ctx context.Context, tx *db.ClusterTx) error {
-				return tx.DeleteInstance(ctx, projectName, snapInstName)
-			})
-			if err != nil {
-				return err
-			}
-		}
-
-		if dbVolume != nil {
-			err := s.DB.Cluster.Transaction(ctx, func(ctx context.Context, tx *db.ClusterTx) error {
-				return tx.RemoveStoragePoolVolume(ctx, projectName, snapInstName, instanceDBVolType, pool.ID())
-			})
-			if err != nil {
-				return err
-			}
-		}
-
 		baseImage := snap.Config["volatile.base_image"]
 
-		arch, err := osarch.ArchitectureId(snap.Architecture)
+		arch, err := osarch.ArchitectureID(snap.Architecture)
 		if err != nil {
 			return err
 		}
@@ -948,11 +931,11 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 
 		// Add root device if needed.
 		if snap.Devices == nil {
-			snap.Devices = make(map[string]map[string]string, 0)
+			snap.Devices = make(map[string]map[string]string)
 		}
 
 		if snap.ExpandedDevices == nil {
-			snap.ExpandedDevices = make(map[string]map[string]string, 0)
+			snap.ExpandedDevices = make(map[string]map[string]string)
 		}
 
 		internalImportRootDevicePopulate(instancePoolName, snap.Devices, snap.ExpandedDevices, profiles)
@@ -976,7 +959,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 			return fmt.Errorf("Failed creating instance snapshot record %q: %w", snap.Name, err)
 		}
 
-		revert.Add(cleanup)
+		reverter.Add(cleanup)
 		defer snapInstOp.Done(err)
 
 		// Recreate missing mountpoints and symlinks.
@@ -991,7 +974,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 		}
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -1076,7 +1059,7 @@ func internalImportRootDevicePopulate(instancePoolName string, localDevices map[
 		// If there is already a device called "root" in the instance's config, but it does not qualify as
 		// a root disk, then try to find a free name for the new root disk device.
 		rootDevName := "root"
-		for i := 0; i < 100; i++ {
+		for i := range 100 {
 			if localDevices[rootDevName] == nil {
 				break
 			}
@@ -1089,7 +1072,7 @@ func internalImportRootDevicePopulate(instancePoolName string, localDevices map[
 	}
 }
 
-func internalGC(d *Daemon, r *http.Request) response.Response {
+func internalGC(_ *Daemon, _ *http.Request) response.Response {
 	logger.Infof("Started forced garbage collection run")
 	runtime.GC()
 	runtimeDebug.FreeOSMemory()
@@ -1106,19 +1089,19 @@ func internalGC(d *Daemon, r *http.Request) response.Response {
 	return response.EmptySyncResponse
 }
 
-func internalRAFTSnapshot(d *Daemon, r *http.Request) response.Response {
+func internalRAFTSnapshot(_ *Daemon, _ *http.Request) response.Response {
 	logger.Warn("Forced RAFT snapshot not supported")
 
-	return response.InternalError(fmt.Errorf("Not supported"))
+	return response.InternalError(errors.New("Not supported"))
 }
 
-func internalBGPState(d *Daemon, r *http.Request) response.Response {
+func internalBGPState(d *Daemon, _ *http.Request) response.Response {
 	s := d.State()
 
 	return response.SyncResponse(true, s.BGP.Debug())
 }
 
-func internalRebalanceLoad(d *Daemon, r *http.Request) response.Response {
+func internalRebalanceLoad(d *Daemon, _ *http.Request) response.Response {
 	err := autoRebalanceCluster(context.TODO(), d)
 	if err != nil {
 		return response.SmartError(err)
