@@ -119,8 +119,8 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 
 	res := internalRecover.ValidateResult{}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// addDependencyError adds an error to the list of dependency errors if not already present in list.
 	addDependencyError := func(err error) {
@@ -145,7 +145,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 				// If the pool DB record doesn't exist, and we are clustered, then don't proceed
 				// any further as we do not support pool DB record recovery when clustered.
 				if s.ServerClustered {
-					return response.BadRequest(fmt.Errorf("Storage pool recovery not supported when clustered"))
+					return response.BadRequest(errors.New("Storage pool recovery not supported when clustered"))
 				}
 
 				// If pool doesn't exist in DB, initialize a temporary pool with the supplied info.
@@ -196,7 +196,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 				}
 			}()
 
-			revert.Add(func() {
+			reverter.Add(func() {
 				cleanupPool := pools[pool.Name()]
 				_, _ = cleanupPool.Unmount() // Defer won't do it if record exists, so unmount on failure.
 			})
@@ -358,7 +358,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 				}
 			}
 
-			revert.Add(func() {
+			reverter.Add(func() {
 				_ = dbStoragePoolDeleteAndUpdateCache(context.Background(), s, pool.Name())
 			})
 
@@ -401,7 +401,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 				if poolVol.Container != nil || poolVol.Bucket != nil {
 					continue // Skip instance volumes and buckets.
 				} else if poolVol.Container == nil && poolVol.Volume == nil {
-					return response.SmartError(fmt.Errorf("Volume is neither instance nor custom volume"))
+					return response.SmartError(errors.New("Volume is neither instance nor custom volume"))
 				}
 
 				// Import custom volume and any snapshots.
@@ -410,7 +410,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 					return response.SmartError(fmt.Errorf("Failed importing custom volume %q in project %q: %w", poolVol.Volume.Name, projectName, err))
 				}
 
-				revert.Add(cleanup)
+				reverter.Add(cleanup)
 			}
 
 			// Recover unknown buckets.
@@ -426,7 +426,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 					return response.SmartError(fmt.Errorf("Failed importing bucket %q in project %q: %w", poolVol.Bucket.Name, projectName, err))
 				}
 
-				revert.Add(cleanup)
+				reverter.Add(cleanup)
 			}
 		}
 	}
@@ -464,7 +464,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 					return response.SmartError(fmt.Errorf("Failed creating instance %q record in project %q: %w", poolVol.Container.Name, projectName, err))
 				}
 
-				revert.Add(cleanup)
+				reverter.Add(cleanup)
 
 				// Recover instance volume snapshots.
 				for _, poolInstSnap := range poolVol.Snapshots {
@@ -482,7 +482,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 						return response.SmartError(fmt.Errorf("Failed creating instance %q snapshot %q record in project %q: %w", poolVol.Container.Name, poolInstSnap.Name, projectName, err))
 					}
 
-					revert.Add(cleanup)
+					reverter.Add(cleanup)
 				}
 
 				// Recreate instance mount path and symlinks (must come after snapshot recovery).
@@ -491,7 +491,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 					return response.SmartError(fmt.Errorf("Failed importing instance %q in project %q: %w", poolVol.Container.Name, projectName, err))
 				}
 
-				revert.Add(cleanup)
+				reverter.Add(cleanup)
 
 				// Reinitialize the instance's root disk quota even if no size specified (allows the storage driver the
 				// opportunity to reinitialize the quota based on the new storage volume's DB ID).
@@ -506,7 +506,7 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 		}
 	}
 
-	revert.Success()
+	reverter.Success()
 	return response.EmptySyncResponse
 }
 
@@ -514,16 +514,16 @@ func internalRecoverScan(ctx context.Context, s *state.State, userPools []api.St
 // Returns a revert fail function that can be used to undo this function if a subsequent step fails.
 func internalRecoverImportInstance(s *state.State, pool storagePools.Pool, projectName string, poolVol *backupConfig.Config, profiles []api.Profile) (instance.Instance, revert.Hook, error) {
 	if poolVol.Container == nil {
-		return nil, nil, fmt.Errorf("Pool volume is not an instance volume")
+		return nil, nil, errors.New("Pool volume is not an instance volume")
 	}
 
 	// Add root device if needed.
 	if poolVol.Container.Devices == nil {
-		poolVol.Container.Devices = make(map[string]map[string]string, 0)
+		poolVol.Container.Devices = make(map[string]map[string]string)
 	}
 
 	if poolVol.Container.ExpandedDevices == nil {
-		poolVol.Container.ExpandedDevices = make(map[string]map[string]string, 0)
+		poolVol.Container.ExpandedDevices = make(map[string]map[string]string)
 	}
 
 	internalImportRootDevicePopulate(pool.Name(), poolVol.Container.Devices, poolVol.Container.ExpandedDevices, profiles)
@@ -534,7 +534,7 @@ func internalRecoverImportInstance(s *state.State, pool storagePools.Pool, proje
 	}
 
 	if dbInst.Type < 0 {
-		return nil, nil, fmt.Errorf("Invalid instance type")
+		return nil, nil, errors.New("Invalid instance type")
 	}
 
 	inst, instOp, cleanup, err := instance.CreateInternal(s, *dbInst, nil, false, true)
@@ -550,21 +550,21 @@ func internalRecoverImportInstance(s *state.State, pool storagePools.Pool, proje
 // internalRecoverImportInstance recreates the database records for an instance snapshot.
 func internalRecoverImportInstanceSnapshot(s *state.State, pool storagePools.Pool, projectName string, poolVol *backupConfig.Config, snap *api.InstanceSnapshot, profiles []api.Profile) (revert.Hook, error) {
 	if poolVol.Container == nil || snap == nil {
-		return nil, fmt.Errorf("Pool volume is not an instance volume")
+		return nil, errors.New("Pool volume is not an instance volume")
 	}
 
 	// Add root device if needed.
 	if snap.Devices == nil {
-		snap.Devices = make(map[string]map[string]string, 0)
+		snap.Devices = make(map[string]map[string]string)
 	}
 
 	if snap.ExpandedDevices == nil {
-		snap.ExpandedDevices = make(map[string]map[string]string, 0)
+		snap.ExpandedDevices = make(map[string]map[string]string)
 	}
 
 	internalImportRootDevicePopulate(pool.Name(), snap.Devices, snap.ExpandedDevices, profiles)
 
-	arch, err := osarch.ArchitectureId(snap.Architecture)
+	arch, err := osarch.ArchitectureID(snap.Architecture)
 	if err != nil {
 		return nil, err
 	}
