@@ -4,6 +4,7 @@ import (
 	"bytes"
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"net"
@@ -260,16 +261,26 @@ func projectUsedBy(ctx context.Context, tx *db.ClusterTx, project *cluster.Proje
 
 	usedBy = append(usedBy, networks...)
 
-	networkACLs, err := tx.GetNetworkACLURIs(ctx, project.ID, project.Name)
+	acls, err := cluster.GetNetworkACLs(ctx, tx.Tx(), cluster.NetworkACLFilter{Project: &project.Name})
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Unable to get URIs for network acl: %w", err)
 	}
 
-	usedBy = append(usedBy, networkACLs...)
+	for _, acl := range acls {
+		apiNetworkACL := api.NetworkACL{NetworkACLPost: api.NetworkACLPost{Name: acl.Name}}
+		usedBy = append(usedBy, apiNetworkACL.URL(version.APIVersion, project.Name).String())
+	}
 
-	networkZones, err := tx.GetNetworkZoneURIs(ctx, project.ID, project.Name)
+	var zones []cluster.NetworkZone
+	zones, err = cluster.GetNetworkZones(ctx, tx.Tx(), cluster.NetworkZoneFilter{Project: &project.Name})
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Unable to get URIs for network zones: %w", err)
+	}
+
+	// Create URIs for each zone.
+	networkZones := make([]string, len(zones))
+	for i, zone := range zones {
+		networkZones[i] = api.NewURL().Path(version.APIVersion, "network-zones", zone.Name).Project(project.Name).String()
 	}
 
 	usedBy = append(usedBy, networkZones...)
@@ -352,6 +363,11 @@ func projectsPost(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Quick checks.
+	err = validate.IsAPIName(project.Name, false)
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid project name: %w", err))
+	}
+
 	err = projectValidateName(project.Name)
 	if err != nil {
 		return response.BadRequest(err)
@@ -724,7 +740,7 @@ func projectChange(ctx context.Context, s *state.State, project *api.Project, re
 	// Quick checks.
 	if len(featuresChanged) > 0 {
 		if project.Name == api.ProjectDefaultName {
-			return response.BadRequest(fmt.Errorf("You can't change the features of the default project"))
+			return response.BadRequest(errors.New("You can't change the features of the default project"))
 		}
 
 		// Consider the project empty if it is only used by the default profile.
@@ -842,7 +858,7 @@ func projectPost(d *Daemon, r *http.Request) response.Response {
 
 	// Quick checks.
 	if name == api.ProjectDefaultName {
-		return response.Forbidden(fmt.Errorf("The 'default' project cannot be renamed"))
+		return response.Forbidden(errors.New("The 'default' project cannot be renamed"))
 	}
 
 	// Perform the rename.
@@ -869,7 +885,7 @@ func projectPost(d *Daemon, r *http.Request) response.Response {
 			}
 
 			if !empty {
-				return fmt.Errorf("Only empty projects can be renamed")
+				return errors.New("Only empty projects can be renamed")
 			}
 
 			id, err = cluster.GetProjectID(ctx, tx.Tx(), name)
@@ -877,9 +893,14 @@ func projectPost(d *Daemon, r *http.Request) response.Response {
 				return fmt.Errorf("Failed getting project ID for project %q: %w", name, err)
 			}
 
+			err = validate.IsAPIName(name, false)
+			if err != nil {
+				return fmt.Errorf("Invalid project name: %w", err)
+			}
+
 			err = projectValidateName(req.Name)
 			if err != nil {
-				return err
+				return fmt.Errorf("Invalid project name: %w", err)
 			}
 
 			return cluster.RenameProject(ctx, tx.Tx(), name, req.Name)
@@ -942,7 +963,7 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 
 	// Quick checks.
 	if name == api.ProjectDefaultName {
-		return response.Forbidden(fmt.Errorf("The 'default' project cannot be deleted"))
+		return response.Forbidden(errors.New("The 'default' project cannot be deleted"))
 	}
 
 	var id int64
@@ -960,7 +981,7 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 			}
 
 			if !empty {
-				return fmt.Errorf("Only empty projects can be removed.")
+				return errors.New("Only empty projects can be removed.")
 			}
 		} else {
 			usedBy, err = projectUsedBy(ctx, tx, project)
@@ -1211,7 +1232,7 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 
 		// Check if anything is left.
 		if count != 0 {
-			return response.BadRequest(fmt.Errorf("Project couldn't be automatically emptied"))
+			return response.BadRequest(errors.New("Project couldn't be automatically emptied"))
 		}
 	}
 
@@ -1329,7 +1350,7 @@ func projectValidateConfig(s *state.State, config map[string]string) error {
 	projectConfigKeys := map[string]func(value string) error{
 		// gendoc:generate(entity=project, group=specific, key=backups.compression_algorithm)
 		// Specify which compression algorithm to use for backups in this project.
-		// Possible values are `bzip2`, `gzip`, `lzma`, `xz`, or `none`.
+		// Possible values are `bzip2`, `gzip`, `lz4`, `lzma`, `xz`, `zstd` or `none`.
 		// ---
 		//  type: string
 		//  shortdesc: Compression algorithm to use for backups
@@ -1405,7 +1426,7 @@ func projectValidateConfig(s *state.State, config map[string]string) error {
 		"images.auto_update_interval": validate.Optional(validate.IsInt64),
 
 		// gendoc:generate(entity=project, group=specific, key=images.compression_algorithm)
-		// Possible values are `bzip2`, `gzip`, `lzma`, `xz`, or `none`.
+		// Possible values are `bzip2`, `gzip`, `lz4`, `lzma`, `xz`, `zstd` or `none`.
 		// ---
 		//  type: string
 		//  shortdesc: Compression algorithm to use for new images in the project
@@ -1817,35 +1838,23 @@ func projectValidateConfig(s *state.State, config map[string]string) error {
 	// be bypassed by settings from the default project's profiles that are not checked against this project's
 	// restrictions when they are configured.
 	if util.IsTrue(config["restricted"]) && util.IsFalse(config["features.profiles"]) {
-		return fmt.Errorf("Projects without their own profiles cannot be restricted")
+		return errors.New("Projects without their own profiles cannot be restricted")
 	}
 
 	return nil
 }
 
 func projectValidateName(name string) error {
-	if name == "" {
-		return fmt.Errorf("No name provided")
-	}
-
-	if strings.Contains(name, "/") {
-		return fmt.Errorf("Project names may not contain slashes")
-	}
-
-	if strings.Contains(name, " ") {
-		return fmt.Errorf("Project names may not contain spaces")
-	}
-
 	if strings.Contains(name, "_") {
-		return fmt.Errorf("Project names may not contain underscores")
+		return errors.New("Project names may not contain underscores")
 	}
 
 	if strings.Contains(name, "'") || strings.Contains(name, `"`) {
-		return fmt.Errorf("Project names may not contain quotes")
+		return errors.New("Project names may not contain quotes")
 	}
 
 	if name == "*" {
-		return fmt.Errorf("Reserved project name")
+		return errors.New("Reserved project name")
 	}
 
 	if slices.Contains([]string{".", ".."}, name) {
@@ -1963,6 +1972,11 @@ func projectAccess(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Quick checks.
+	err = validate.IsAPIName(name, false)
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid project name: %w", err))
+	}
+
 	err = projectValidateName(name)
 	if err != nil {
 		return response.BadRequest(err)
