@@ -25,7 +25,6 @@ import (
 	"github.com/gorilla/mux"
 	liblxc "github.com/lxc/go-lxc"
 	"golang.org/x/sys/unix"
-	yaml "gopkg.in/yaml.v2"
 
 	internalIO "github.com/lxc/incus/v6/internal/io"
 	"github.com/lxc/incus/v6/internal/linux"
@@ -50,7 +49,7 @@ import (
 	"github.com/lxc/incus/v6/internal/server/instance"
 	instanceDrivers "github.com/lxc/incus/v6/internal/server/instance/drivers"
 	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
-	"github.com/lxc/incus/v6/internal/server/loki"
+	"github.com/lxc/incus/v6/internal/server/logging"
 	"github.com/lxc/incus/v6/internal/server/network/ovn"
 	"github.com/lxc/incus/v6/internal/server/network/ovs"
 	networkZone "github.com/lxc/incus/v6/internal/server/network/zone"
@@ -153,7 +152,7 @@ type Daemon struct {
 	serverName      string
 	serverClustered bool
 
-	lokiClient *loki.Client
+	loggingController *logging.Controller
 
 	// Authorization.
 	authorizer auth.Authorizer
@@ -417,7 +416,7 @@ func (d *Daemon) checkTrustedClient(r *http.Request) error {
 			return err
 		}
 
-		return fmt.Errorf("Not authorized")
+		return errors.New("Not authorized")
 	}
 
 	return nil
@@ -507,22 +506,22 @@ func (d *Daemon) Authenticate(w http.ResponseWriter, r *http.Request) (bool, str
 
 	// DevIncus unix socket credentials on main API.
 	if r.RemoteAddr == "@dev_incus" {
-		return false, "", "", fmt.Errorf("Main API query can't come from /dev/incus socket")
+		return false, "", "", errors.New("Main API query can't come from /dev/incus socket")
 	}
 
 	// Cluster notification with wrong certificate.
 	if isClusterNotification(r) {
-		return false, "", "", fmt.Errorf("Cluster notification isn't using trusted server certificate")
+		return false, "", "", errors.New("Cluster notification isn't using trusted server certificate")
 	}
 
 	// Cluster internal client with wrong certificate.
 	if isClusterInternal(r) {
-		return false, "", "", fmt.Errorf("Cluster internal client isn't using trusted server certificate")
+		return false, "", "", errors.New("Cluster internal client isn't using trusted server certificate")
 	}
 
 	// Bad query, no TLS found.
 	if r.TLS == nil {
-		return false, "", "", fmt.Errorf("Bad/missing TLS on network query")
+		return false, "", "", errors.New("Bad/missing TLS on network query")
 	}
 
 	// Load the certificates.
@@ -633,7 +632,7 @@ func (d *Daemon) createCmd(restAPI *mux.Router, version string, c APIEndpoint) {
 			select {
 			case <-d.setupChan:
 			default:
-				response := response.Unavailable(fmt.Errorf("Daemon is starting up"))
+				response := response.Unavailable(errors.New("Daemon is starting up"))
 				_ = response.Render(w)
 				return
 			}
@@ -642,8 +641,8 @@ func (d *Daemon) createCmd(restAPI *mux.Router, version string, c APIEndpoint) {
 		// Authentication
 		trusted, username, protocol, err := d.Authenticate(w, r)
 		if err != nil {
-			_, ok := err.(*oidc.AuthError)
-			if ok {
+			var authError *oidc.AuthError
+			if errors.As(err, &authError) {
 				// Ensure the OIDC headers are set if needed.
 				if d.oidcVerifier != nil {
 					_ = d.oidcVerifier.WriteHeaders(w)
@@ -741,8 +740,8 @@ func (d *Daemon) createCmd(restAPI *mux.Router, version string, c APIEndpoint) {
 			return false
 		}
 
-		if d.shutdownCtx.Err() == context.Canceled && !allowedDuringShutdown() {
-			_ = response.Unavailable(fmt.Errorf("Shutting down")).Render(w)
+		if errors.Is(d.shutdownCtx.Err(), context.Canceled) && !allowedDuringShutdown() {
+			_ = response.Unavailable(errors.New("Shutting down")).Render(w)
 			return
 		}
 
@@ -761,6 +760,12 @@ func (d *Daemon) createCmd(restAPI *mux.Router, version string, c APIEndpoint) {
 				return response.Forbidden(errors.New("You must be authenticated"))
 			}
 
+			// Protect against CSRF when using UI with browser that supports Fetch metadata.
+			// Deny Sec-Fetch-Site when set to cross-origin or same-site.
+			if slices.Contains([]string{"cross-site", "same-site"}, r.Header.Get("Sec-Fetch-Site")) {
+				return response.ErrorResponse(http.StatusForbidden, "Forbidden Sec-Fetch-Site header value")
+			}
+
 			// Call the access handler if there is one.
 			if action.AccessHandler != nil {
 				resp := action.AccessHandler(d, r)
@@ -866,48 +871,6 @@ func (d *Daemon) Init() error {
 	return nil
 }
 
-func (d *Daemon) setupLoki(URL string, cert string, key string, caCert string, instanceName string, logLevel string, labels []string, types []string) error {
-	// Stop any existing loki client.
-	if d.lokiClient != nil {
-		d.lokiClient.Stop()
-	}
-
-	// Check basic requirements for starting a new client.
-	if URL == "" || logLevel == "" || len(types) == 0 {
-		return nil
-	}
-
-	// Validate the URL.
-	u, err := url.Parse(URL)
-	if err != nil {
-		return err
-	}
-
-	// Handle standalone systems.
-	var location string
-	if !d.serverClustered {
-		hostname, err := os.Hostname()
-		if err != nil {
-			return err
-		}
-
-		location = hostname
-		if instanceName == "" {
-			instanceName = hostname
-		}
-	} else if instanceName == "" {
-		instanceName = d.serverName
-	}
-
-	// Start a new client.
-	d.lokiClient = loki.NewClient(d.shutdownCtx, u, cert, key, caCert, instanceName, location, logLevel, labels, types)
-
-	// Attach the new client to the log handler.
-	d.internalListener.AddHandler("loki", d.lokiClient.HandleEvent)
-
-	return nil
-}
-
 func (d *Daemon) init() error {
 	var err error
 
@@ -1396,7 +1359,7 @@ func (d *Daemon) init() error {
 
 	// Mount the storage pools.
 	logger.Infof("Initializing storage pools")
-	err = storageStartup(d.State(), false)
+	err = storageStartup(d.State())
 	if err != nil {
 		return err
 	}
@@ -1465,7 +1428,6 @@ func (d *Daemon) init() error {
 	d.proxy = proxy.FromConfig(d.globalConfig.ProxyHTTPS(), d.globalConfig.ProxyHTTP(), d.globalConfig.ProxyIgnoreHosts())
 
 	d.gateway.HeartbeatOfflineThreshold = d.globalConfig.OfflineThreshold()
-	lokiURL, lokiUsername, lokiPassword, lokiCACert, lokiInstance, lokiLoglevel, lokiLabels, lokiTypes := d.globalConfig.LokiServer()
 	oidcIssuer, oidcClientID, oidcScope, oidcAudience, oidcClaim := d.globalConfig.OIDCServer()
 	syslogSocketEnabled := d.localConfig.SyslogSocket()
 	openfgaAPIURL, openfgaAPIToken, openfgaStoreID := d.globalConfig.OpenFGA()
@@ -1475,12 +1437,10 @@ func (d *Daemon) init() error {
 	d.endpoints.NetworkUpdateTrustedProxy(d.globalConfig.HTTPSTrustedProxy())
 	d.globalConfigMu.Unlock()
 
-	// Setup Loki logger.
-	if lokiURL != "" {
-		err = d.setupLoki(lokiURL, lokiUsername, lokiPassword, lokiCACert, lokiInstance, lokiLoglevel, lokiLabels, lokiTypes)
-		if err != nil {
-			return err
-		}
+	d.loggingController = logging.NewLoggingController(d.internalListener)
+	err = d.loggingController.Setup(d.State())
+	if err != nil {
+		return err
 	}
 
 	// Setup syslog listener.
@@ -1796,6 +1756,10 @@ func (d *Daemon) Stop(ctx context.Context, sig os.Signal) error {
 	// Cancelling the context will make everyone aware that we're shutting down.
 	d.shutdownCancel()
 
+	if d.loggingController != nil {
+		d.loggingController.Shutdown()
+	}
+
 	if d.gateway != nil {
 		d.stopClusterTasks()
 
@@ -1865,7 +1829,7 @@ func (d *Daemon) Stop(ctx context.Context, sig os.Signal) error {
 
 		// Full shutdown requested.
 		if sig == unix.SIGPWR {
-			instancesShutdown(s, instances)
+			instancesShutdown(instances)
 
 			logger.Info("Stopping networks")
 			networkShutdown(s)
@@ -1998,10 +1962,10 @@ func (d *Daemon) setupOpenFGA(apiURL string, apiToken string, storeID string) er
 		"openfga.store.id":  storeID,
 	}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
-	revert.Add(func() {
+	reverter.Add(func() {
 		// Reset to default authorizer.
 		d.authorizer, _ = auth.LoadAuthorizer(d.shutdownCtx, auth.DriverTLS, logger.Log, d.clientCerts)
 	})
@@ -2242,7 +2206,7 @@ func (d *Daemon) setupOpenFGA(apiURL string, apiToken string, storeID string) er
 
 	d.authorizer = openfgaAuthorizer
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -2356,9 +2320,7 @@ func (d *Daemon) hasMemberStateChanged(heartbeatData *cluster.APIHeartbeat) bool
 }
 
 // heartbeatHandler handles heartbeat requests from other cluster members.
-func (d *Daemon) heartbeatHandler(w http.ResponseWriter, r *http.Request, isLeader bool, hbData *cluster.APIHeartbeat) {
-	s := d.State()
-
+func (d *Daemon) heartbeatHandler(w http.ResponseWriter, _ *http.Request, isLeader bool, hbData *cluster.APIHeartbeat) {
 	var err error
 
 	// Look for time skews.
@@ -2448,55 +2410,6 @@ func (d *Daemon) heartbeatHandler(w http.ResponseWriter, r *http.Request, isLead
 
 		logger.Debug("Partial heartbeat received")
 	}
-
-	// Refresh cluster member resource info cache.
-	var muRefresh sync.Mutex
-
-	for _, member := range hbData.Members {
-		// Ignore offline servers.
-		if !member.Online {
-			continue
-		}
-
-		if member.Name == s.ServerName {
-			continue
-		}
-
-		go func(name string, address string) {
-			muRefresh.Lock()
-			defer muRefresh.Unlock()
-
-			// Check if we have a recent local cache entry already.
-			resourcesPath := internalUtil.CachePath("resources", fmt.Sprintf("%s.yaml", name))
-			fi, err := os.Stat(resourcesPath)
-			if err == nil && time.Since(fi.ModTime()) < time.Hour {
-				return
-			}
-
-			// Connect to the server.
-			client, err := cluster.Connect(address, s.Endpoints.NetworkCert(), s.ServerCert(), nil, true)
-			if err != nil {
-				return
-			}
-
-			// Get the server resources.
-			resources, err := client.GetServerResources()
-			if err != nil {
-				return
-			}
-
-			// Write to cache.
-			data, err := yaml.Marshal(resources)
-			if err != nil {
-				return
-			}
-
-			err = os.WriteFile(resourcesPath, data, 0o600)
-			if err != nil {
-				return
-			}
-		}(member.Name, member.Address)
-	}
 }
 
 // nodeRefreshTask is run when a full state heartbeat is sent (on the leader) or received (by a non-leader member).
