@@ -86,12 +86,15 @@ var patches = []patch{
 	{name: "runtime_directory", stage: patchPostDaemonStorage, run: patchRuntimeDirectory},
 	{name: "lvm_node_force_reuse", stage: patchPostDaemonStorage, run: patchLvmForceReuseKey},
 	{name: "auth_openfga_viewer", stage: patchPostNetworks, run: patchGenericAuthorization},
+	{name: "db_json_columns", stage: patchPreDaemonStorage, run: patchConvertJSONColumn},
 }
 
+type patchRun func(name string, d *Daemon) error
+
 type patch struct {
 	name  string
 	stage patchStage
-	run   func(name string, d *Daemon) error
+	run   patchRun
 }
 
 func (p *patch) apply(d *Daemon) error {
@@ -155,7 +158,7 @@ func patchesApply(d *Daemon, stage patchStage) error {
 
 // Patches begin here
 
-func patchDnsmasqEntriesIncludeDeviceName(name string, d *Daemon) error {
+func patchDnsmasqEntriesIncludeDeviceName(_ string, d *Daemon) error {
 	err := network.UpdateDNSMasqStatic(d.State(), "")
 	if err != nil {
 		return err
@@ -164,7 +167,7 @@ func patchDnsmasqEntriesIncludeDeviceName(name string, d *Daemon) error {
 	return nil
 }
 
-func patchRemoveWarningsWithEmptyNode(name string, d *Daemon) error {
+func patchRemoveWarningsWithEmptyNode(_ string, d *Daemon) error {
 	err := d.db.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 		warnings, err := dbCluster.GetWarnings(ctx, tx.Tx())
 		if err != nil {
@@ -286,7 +289,7 @@ func patchClusteringServerCertTrust(name string, d *Daemon) error {
 // It was decided that the user experience of having the default actions at the ACL level was confusing when using
 // multiple ACLs, and that the interplay between conflicting default actions on multiple ACLs was difficult to
 // understand. Instead it will be replace with a network and NIC level defaults settings.
-func patchNetworkACLRemoveDefaults(name string, d *Daemon) error {
+func patchNetworkACLRemoveDefaults(_ string, d *Daemon) error {
 	var err error
 	var projectNames []string
 
@@ -302,13 +305,13 @@ func patchNetworkACLRemoveDefaults(name string, d *Daemon) error {
 	err = d.db.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 		// Get ACLs in projects.
 		for _, projectName := range projectNames {
-			aclNames, err := tx.GetNetworkACLs(ctx, projectName)
+			acls, err := dbCluster.GetNetworkACLs(ctx, tx.Tx(), dbCluster.NetworkACLFilter{Project: &projectName})
 			if err != nil {
 				return err
 			}
 
-			for _, aclName := range aclNames {
-				aclID, acl, err := tx.GetNetworkACL(ctx, projectName, aclName)
+			for _, acl := range acls {
+				aclAPI, err := acl.ToAPI(ctx, tx.Tx())
 				if err != nil {
 					return err
 				}
@@ -316,23 +319,23 @@ func patchNetworkACLRemoveDefaults(name string, d *Daemon) error {
 				modified := false
 
 				// Remove the offending keys if found.
-				_, found := acl.Config["default.action"]
+				_, found := aclAPI.Config["default.action"]
 				if found {
-					delete(acl.Config, "default.action")
+					delete(aclAPI.Config, "default.action")
 					modified = true
 				}
 
-				_, found = acl.Config["default.logged"]
+				_, found = aclAPI.Config["default.logged"]
 				if found {
-					delete(acl.Config, "default.logged")
+					delete(aclAPI.Config, "default.logged")
 					modified = true
 				}
 
 				// Write back modified config if needed.
 				if modified {
-					err = tx.UpdateNetworkACL(ctx, aclID, &acl.NetworkACLPut)
+					err = dbCluster.UpdateNetworkACLAPI(ctx, tx.Tx(), int64(acl.ID), &aclAPI.NetworkACLPut)
 					if err != nil {
-						return fmt.Errorf("Failed updating network ACL %d: %w", aclID, err)
+						return fmt.Errorf("Failed updating network ACL %d: %w", acl.ID, err)
 					}
 				}
 			}
@@ -427,7 +430,7 @@ PRAGMA legacy_alter_table = OFF; -- So views check integrity again.
 }
 
 // patchVMRenameUUIDKey renames the volatile.vm.uuid key to volatile.uuid in instance and snapshot configs.
-func patchVMRenameUUIDKey(name string, d *Daemon) error {
+func patchVMRenameUUIDKey(_ string, d *Daemon) error {
 	oldUUIDKey := "volatile.vm.uuid"
 	newUUIDKey := "volatile.uuid"
 
@@ -485,9 +488,9 @@ func patchVMRenameUUIDKey(name string, d *Daemon) error {
 }
 
 // patchThinpoolTypoFix renames any config incorrectly set config file entries due to the lvm.thinpool_name typo.
-func patchThinpoolTypoFix(name string, d *Daemon) error {
-	revert := revert.New()
-	defer revert.Fail()
+func patchThinpoolTypoFix(_ string, d *Daemon) error {
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Setup a transaction.
 	tx, err := d.db.Cluster.Begin()
@@ -495,7 +498,7 @@ func patchThinpoolTypoFix(name string, d *Daemon) error {
 		return fmt.Errorf("Failed to begin transaction: %w", err)
 	}
 
-	revert.Add(func() { _ = tx.Rollback() })
+	reverter.Add(func() { _ = tx.Rollback() })
 
 	// Fetch the IDs of all existing nodes.
 	nodeIDs, err := query.SelectIntegers(context.TODO(), tx, "SELECT id FROM nodes")
@@ -546,13 +549,13 @@ INSERT INTO storage_pools_config(storage_pool_id, node_id, key, value)
 		return fmt.Errorf("Failed to commit transaction: %w", err)
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
 // patchNetworkOVNRemoveRoutes removes the "ipv4.routes.external" and "ipv6.routes.external" settings from OVN
 // networks. It was decided that the OVN NIC level equivalent settings were sufficient.
-func patchNetworkOVNRemoveRoutes(name string, d *Daemon) error {
+func patchNetworkOVNRemoveRoutes(_ string, d *Daemon) error {
 	err := d.db.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 		projectNetworks, err := tx.GetCreatedNetworks(ctx)
 		if err != nil {
@@ -604,7 +607,7 @@ func patchNetworkOVNRemoveRoutes(name string, d *Daemon) error {
 // This is to ensure existing networks retain the old behaviour of always having NAT enabled as we introduce
 // the new NAT settings which default to disabled if not specified.
 // patchNetworkCearBridgeVolatileHwaddr removes the unsupported `volatile.bridge.hwaddr` config key from networks.
-func patchNetworkOVNEnableNAT(name string, d *Daemon) error {
+func patchNetworkOVNEnableNAT(_ string, d *Daemon) error {
 	err := d.db.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 		projectNetworks, err := tx.GetCreatedNetworks(ctx)
 		if err != nil {
@@ -651,7 +654,7 @@ func patchNetworkOVNEnableNAT(name string, d *Daemon) error {
 }
 
 // Moves backups from internalUtil.VarPath("backups") to internalUtil.VarPath("backups", "instances").
-func patchMoveBackupsInstances(name string, d *Daemon) error {
+func patchMoveBackupsInstances(_ string, _ *Daemon) error {
 	if !util.PathExists(internalUtil.VarPath("backups")) {
 		return nil // Nothing to do, no backups directory.
 	}
@@ -704,7 +707,7 @@ func patchGenericNetwork(f func(name string, d *Daemon) error) func(name string,
 	}
 }
 
-func patchClusteringDropDatabaseRole(name string, d *Daemon) error {
+func patchClusteringDropDatabaseRole(_ string, d *Daemon) error {
 	return d.State().DB.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 		members, err := tx.GetNodes(ctx)
 		if err != nil {
@@ -722,7 +725,7 @@ func patchClusteringDropDatabaseRole(name string, d *Daemon) error {
 }
 
 // patchNetworkClearBridgeVolatileHwaddr removes the unsupported `volatile.bridge.hwaddr` config key from networks.
-func patchNetworkClearBridgeVolatileHwaddr(name string, d *Daemon) error {
+func patchNetworkClearBridgeVolatileHwaddr(_ string, d *Daemon) error {
 	// Use api.ProjectDefaultName, as bridge networks don't support projects.
 	projectName := api.ProjectDefaultName
 
@@ -759,7 +762,7 @@ func patchNetworkClearBridgeVolatileHwaddr(name string, d *Daemon) error {
 
 // patchStorageRenameCustomISOBlockVolumes renames existing custom ISO volumes by adding the ".iso" suffix so they can be distinguished from regular custom block volumes.
 // This patch doesn't use the patchGenericStorage function because the storage drivers themselves aren't aware of custom ISO volumes.
-func patchStorageRenameCustomISOBlockVolumes(name string, d *Daemon) error {
+func patchStorageRenameCustomISOBlockVolumes(_ string, d *Daemon) error {
 	s := d.State()
 
 	var pools []string
@@ -806,7 +809,7 @@ func patchStorageRenameCustomISOBlockVolumes(name string, d *Daemon) error {
 	}
 
 	volTypeCustom := db.StoragePoolVolumeTypeCustom
-	customPoolVolumes := make(map[string][]*db.StorageVolume, 0)
+	customPoolVolumes := make(map[string][]*db.StorageVolume)
 
 	err = s.DB.Cluster.Transaction(s.ShutdownCtx, func(ctx context.Context, tx *db.ClusterTx) error {
 		for _, pool := range pools {
@@ -872,7 +875,7 @@ func patchStorageRenameCustomISOBlockVolumes(name string, d *Daemon) error {
 }
 
 // patchZfsSetContentTypeUserProperty adds the `incus:content_type` user property to custom storage volumes. In case of recovery, this allows for proper detection of block-mode enabled volumes.
-func patchZfsSetContentTypeUserProperty(name string, d *Daemon) error {
+func patchZfsSetContentTypeUserProperty(_ string, d *Daemon) error {
 	s := d.State()
 
 	var pools []string
@@ -895,7 +898,7 @@ func patchZfsSetContentTypeUserProperty(name string, d *Daemon) error {
 	}
 
 	volTypeCustom := db.StoragePoolVolumeTypeCustom
-	customPoolVolumes := make(map[string][]*db.StorageVolume, 0)
+	customPoolVolumes := make(map[string][]*db.StorageVolume)
 
 	err = s.DB.Cluster.Transaction(s.ShutdownCtx, func(ctx context.Context, tx *db.ClusterTx) error {
 		for _, pool := range pools {
@@ -959,7 +962,7 @@ func patchZfsSetContentTypeUserProperty(name string, d *Daemon) error {
 }
 
 // patchSnapshotsRename renames the "snapshots" directory to "container-snapshots".
-func patchSnapshotsRename(name string, d *Daemon) error {
+func patchSnapshotsRename(_ string, _ *Daemon) error {
 	// Remove what should be an empty directory.
 	os.Remove(internalUtil.VarPath("containers-snapshots"))
 
@@ -992,8 +995,8 @@ func patchStorageZfsUnsetInvalidBlockSettings(_ string, d *Daemon) error {
 	volTypeCustom := db.StoragePoolVolumeTypeCustom
 	volTypeVM := db.StoragePoolVolumeTypeVM
 
-	poolIDNameMap := make(map[int64]string, 0)
-	poolVolumes := make(map[int64][]*db.StorageVolume, 0)
+	poolIDNameMap := make(map[int64]string)
+	poolVolumes := make(map[int64][]*db.StorageVolume)
 
 	err = s.DB.Cluster.Transaction(s.ShutdownCtx, func(ctx context.Context, tx *db.ClusterTx) error {
 		for _, pool := range pools {
@@ -1110,8 +1113,8 @@ func patchStorageZfsUnsetInvalidBlockSettingsV2(_ string, d *Daemon) error {
 	volTypeCustom := db.StoragePoolVolumeTypeCustom
 	volTypeVM := db.StoragePoolVolumeTypeVM
 
-	poolIDNameMap := make(map[int64]string, 0)
-	poolVolumes := make(map[int64][]*db.StorageVolume, 0)
+	poolIDNameMap := make(map[int64]string)
+	poolVolumes := make(map[int64][]*db.StorageVolume)
 
 	err = s.DB.Cluster.Transaction(s.ShutdownCtx, func(ctx context.Context, tx *db.ClusterTx) error {
 		for _, pool := range pools {
@@ -1201,7 +1204,7 @@ func patchStorageZfsUnsetInvalidBlockSettingsV2(_ string, d *Daemon) error {
 	return nil
 }
 
-func patchRuntimeDirectory(name string, d *Daemon) error {
+func patchRuntimeDirectory(_ string, d *Daemon) error {
 	s := d.State()
 
 	// Get the list of local instances.
@@ -1258,9 +1261,9 @@ func patchRuntimeDirectory(name string, d *Daemon) error {
 }
 
 // The lvm.vg.force_reuse config key is node-specific and need to be linked to nodes.
-func patchLvmForceReuseKey(name string, d *Daemon) error {
-	revert := revert.New()
-	defer revert.Fail()
+func patchLvmForceReuseKey(_ string, d *Daemon) error {
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Setup a transaction.
 	tx, err := d.db.Cluster.Begin()
@@ -1268,7 +1271,7 @@ func patchLvmForceReuseKey(name string, d *Daemon) error {
 		return fmt.Errorf("Failed to begin transaction: %w", err)
 	}
 
-	revert.Add(func() { _ = tx.Rollback() })
+	reverter.Add(func() { _ = tx.Rollback() })
 
 	// Fetch the IDs of all existing nodes.
 	nodeIDs, err := query.SelectIntegers(context.TODO(), tx, "SELECT id FROM nodes")
@@ -1317,7 +1320,25 @@ INSERT INTO storage_pools_config(storage_pool_id, node_id, key, value)
 		return fmt.Errorf("Failed to commit transaction: %w", err)
 	}
 
-	revert.Success()
+	reverter.Success()
+	return nil
+}
+
+// The database generator expects valid JSON. An empty string isn't valid JSON.
+func patchConvertJSONColumn(_ string, d *Daemon) error {
+	s := d.State()
+
+	_, err := s.DB.Cluster.DB().Exec(`
+UPDATE networks_acls SET egress="null" WHERE egress="";
+UPDATE networks_acls SET ingress="null" WHERE ingress="";
+UPDATE networks_forwards SET ports="null" WHERE ports="";
+UPDATE networks_load_balancers SET backends="null" WHERE backends="";
+UPDATE networks_load_balancers SET ports="null" WHERE ports="";
+`)
+	if err != nil {
+		return fmt.Errorf("Failed to fix JSON columns: %w", err)
+	}
+
 	return nil
 }
 
