@@ -3,11 +3,12 @@ package main
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
+	"maps"
 	"net/http"
 	"net/url"
 	"slices"
-	"strings"
 	"sync"
 
 	"github.com/gorilla/mux"
@@ -29,6 +30,7 @@ import (
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
 	"github.com/lxc/incus/v6/shared/util"
+	"github.com/lxc/incus/v6/shared/validate"
 )
 
 // Lock to prevent concurrent storage pools creation.
@@ -196,8 +198,9 @@ func storagePoolsGet(d *Daemon, r *http.Request) response.Response {
 		return response.InternalError(err)
 	}
 
-	var linkResults []string
-	var fullResults []api.StoragePool
+	linkResults := make([]string, 0)
+	fullResults := make([]api.StoragePool, 0)
+
 	for _, poolName := range poolNames {
 		// Hide storage pools with a 0 project limit.
 		if slices.Contains(hiddenPoolNames, poolName) {
@@ -312,15 +315,16 @@ func storagePoolsPost(d *Daemon, r *http.Request) response.Response {
 
 	// Quick checks.
 	if req.Name == "" {
-		return response.BadRequest(fmt.Errorf("No name provided"))
+		return response.BadRequest(errors.New("No name provided"))
 	}
 
-	if strings.Contains(req.Name, "/") {
-		return response.BadRequest(fmt.Errorf("Storage pool names may not contain slashes"))
+	err = validate.IsAPIName(req.Name, false)
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid storage pool name: %w", err))
 	}
 
 	if req.Driver == "" {
-		return response.BadRequest(fmt.Errorf("No driver provided"))
+		return response.BadRequest(errors.New("No driver provided"))
 	}
 
 	if req.Config == nil {
@@ -393,7 +397,7 @@ func storagePoolsPost(d *Daemon, r *http.Request) response.Response {
 			return tx.CreatePendingStoragePool(ctx, targetNode, req.Name, req.Driver, req.Config)
 		})
 		if err != nil {
-			if err == db.ErrAlreadyDefined {
+			if errors.Is(err, db.ErrAlreadyDefined) {
 				return response.BadRequest(fmt.Errorf("The storage pool already defined on member %q", targetNode))
 			}
 
@@ -495,7 +499,7 @@ func storagePoolsPostCluster(ctx context.Context, s *state.State, pool *api.Stor
 	if pool != nil {
 		// Check pool isn't already created.
 		if pool.Status == api.StoragePoolStatusCreated {
-			return fmt.Errorf("The storage pool is already created")
+			return errors.New("The storage pool is already created")
 		}
 
 		// Check the requested pool type matches the type created when adding the local member config.
@@ -519,7 +523,7 @@ func storagePoolsPostCluster(ctx context.Context, s *state.State, pool *api.Stor
 		// Check if any global config exists already, if so we should not create global config again.
 		if pool != nil && storagePoolPartiallyCreated(pool) {
 			if len(req.Config) > 0 {
-				return fmt.Errorf("Storage pool already partially created. Please do not specify any global config when re-running create")
+				return errors.New("Storage pool already partially created. Please do not specify any global config when re-running create")
 			}
 
 			logger.Debug("Skipping global storage pool create as global config already partially created", logger.Ctx{"pool": req.Name})
@@ -543,7 +547,7 @@ func storagePoolsPostCluster(ctx context.Context, s *state.State, pool *api.Stor
 	})
 	if err != nil {
 		if response.IsNotFoundError(err) {
-			return fmt.Errorf("Pool not pending on any node (use --target <node> first)")
+			return errors.New("Pool not pending on any node (use --target <node> first)")
 		}
 
 		return err
@@ -559,9 +563,7 @@ func storagePoolsPostCluster(ctx context.Context, s *state.State, pool *api.Stor
 	nodeReq := req
 
 	// Merge node specific config items into global config.
-	for key, value := range configs[s.ServerName] {
-		nodeReq.Config[key] = value
-	}
+	maps.Copy(nodeReq.Config, configs[s.ServerName])
 
 	updatedConfig, err := storagePoolCreateLocal(ctx, s, poolID, req, clientType)
 	if err != nil {
@@ -590,9 +592,7 @@ func storagePoolsPostCluster(ctx context.Context, s *state.State, pool *api.Stor
 		nodeReq.Config = util.CloneMap(req.Config)
 
 		// Merge node specific config items into global config.
-		for key, value := range configs[server.Environment.ServerName] {
-			nodeReq.Config[key] = value
-		}
+		maps.Copy(nodeReq.Config, configs[server.Environment.ServerName])
 
 		err = client.CreateStoragePool(nodeReq)
 		if err != nil {
@@ -805,7 +805,7 @@ func storagePoolPut(d *Daemon, r *http.Request) response.Response {
 	targetNode := request.QueryParam(r, "target")
 
 	if targetNode == "" && pool.Status() != api.StoragePoolStatusCreated {
-		return response.BadRequest(fmt.Errorf("Cannot update storage pool global config when not in created state"))
+		return response.BadRequest(errors.New("Cannot update storage pool global config when not in created state"))
 	}
 
 	// Duplicate config for etag modification and generation.
@@ -1033,7 +1033,7 @@ func storagePoolDelete(d *Daemon, r *http.Request) response.Response {
 		}
 
 		if inUse {
-			return response.BadRequest(fmt.Errorf("The storage pool is currently in use"))
+			return response.BadRequest(errors.New("The storage pool is currently in use"))
 		}
 
 		// Get the cluster notifier
