@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"errors"
 	"fmt"
 	"os"
 	"os/signal"
@@ -22,7 +23,7 @@ func CancelableWait(rawOp any, progress *ProgressRenderer) error {
 	case incus.RemoteOperation:
 		rop = v
 	default:
-		return fmt.Errorf("Invalid operation type for CancelableWait")
+		return errors.New("Invalid operation type for CancelableWait")
 	}
 
 	// Signal handling
@@ -56,13 +57,13 @@ func CancelableWait(rawOp any, progress *ProgressRenderer) error {
 			}
 
 			if err == nil {
-				return fmt.Errorf(i18n.G("Remote operation canceled by user"))
+				return errors.New(i18n.G("Remote operation canceled by user"))
 			}
 
 			count++
 
 			if count == 3 {
-				return fmt.Errorf(i18n.G("User signaled us three times, exiting. The remote operation will keep running"))
+				return errors.New(i18n.G("User signaled us three times, exiting. The remote operation will keep running"))
 			}
 
 			if progress != nil {
