@@ -2,6 +2,7 @@ package oidc
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"net/http"
 	"slices"
@@ -57,7 +58,7 @@ func (o *Verifier) Auth(ctx context.Context, w http.ResponseWriter, r *http.Requ
 		// Both returned errors contain information which are needed for the client to authenticate.
 		parts := strings.Split(auth, "Bearer ")
 		if len(parts) != 2 {
-			return "", &AuthError{fmt.Errorf("Bad authorization token, expected a Bearer token")}
+			return "", &AuthError{errors.New("Bad authorization token, expected a Bearer token")}
 		}
 
 		token = parts[1]
@@ -178,7 +179,7 @@ func (o *Verifier) Logout(w http.ResponseWriter, r *http.Request) {
 
 	// Attempt to end the OIDC session.
 	if provider != nil && token != "" {
-		_, _ = rp.EndSession(r.Context(), provider, token, fmt.Sprintf("https://%s", r.Host), "")
+		_, _ = rp.EndSession(r.Context(), provider, token, fmt.Sprintf("https://%s", r.Host), "", "", nil)
 	}
 
 	// Access token.
@@ -293,7 +294,7 @@ func (o *Verifier) VerifyAccessToken(ctx context.Context, token string) (*oidc.A
 	// Check that the token includes the configured audience.
 	audience := claims.GetAudience()
 	if o.audience != "" && !slices.Contains(audience, o.audience) {
-		return nil, fmt.Errorf("Provided OIDC token doesn't allow the configured audience")
+		return nil, errors.New("Provided OIDC token doesn't allow the configured audience")
 	}
 
 	return claims, nil
@@ -301,9 +302,10 @@ func (o *Verifier) VerifyAccessToken(ctx context.Context, token string) (*oidc.A
 
 // WriteHeaders writes the OIDC configuration as HTTP headers so the client can initatiate the device code flow.
 func (o *Verifier) WriteHeaders(w http.ResponseWriter) error {
-	w.Header().Set("X-Incus-OIDC-issuer", o.issuer)
-	w.Header().Set("X-Incus-OIDC-clientid", o.clientID)
 	w.Header().Set("X-Incus-OIDC-audience", o.audience)
+	w.Header().Set("X-Incus-OIDC-clientid", o.clientID)
+	w.Header().Set("X-Incus-OIDC-issuer", o.issuer)
+	w.Header().Set("X-Incus-OIDC-scopes", strings.Join(o.scopes, ","))
 
 	return nil
 }
