@@ -2,7 +2,9 @@ package bgp
 
 import (
 	"context"
+	"errors"
 	"fmt"
+	"maps"
 	"net"
 	"strconv"
 	"sync"
@@ -69,7 +71,7 @@ func (s *Server) start(address string, asn uint32, routerID net.IP) error {
 
 	// Check if already running
 	if s.bgp != nil {
-		return fmt.Errorf("BGP listener is already running")
+		return errors.New("BGP listener is already running")
 	}
 
 	// Spawn the BGP goroutines.
@@ -113,9 +115,7 @@ func (s *Server) start(address string, asn uint32, routerID net.IP) error {
 
 	// Copy the path list
 	oldPaths := map[string]path{}
-	for pathUUID, path := range s.paths {
-		oldPaths[pathUUID] = path
-	}
+	maps.Copy(oldPaths, s.paths)
 
 	// Add existing paths.
 	s.paths = map[string]path{}
@@ -128,9 +128,7 @@ func (s *Server) start(address string, asn uint32, routerID net.IP) error {
 
 	// Copy the peer list.
 	oldPeers := map[string]peer{}
-	for peerUUID, peer := range s.peers {
-		oldPeers[peerUUID] = peer
-	}
+	maps.Copy(oldPeers, s.peers)
 
 	// Add existing peers.
 	s.peers = map[string]peer{}
@@ -158,9 +156,7 @@ func (s *Server) stop() error {
 
 	// Save the peer list.
 	oldPeers := map[string]peer{}
-	for peerUUID, peer := range s.peers {
-		oldPeers[peerUUID] = peer
-	}
+	maps.Copy(oldPeers, s.peers)
 
 	// Remove all the peers.
 	for _, peer := range s.peers {
@@ -204,8 +200,8 @@ func (s *Server) configure(address string, asn uint32, routerID net.IP) error {
 	oldRouterID := s.routerID
 
 	// Setup reverter.
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Stop the listener.
 	err := s.stop()
@@ -216,7 +212,7 @@ func (s *Server) configure(address string, asn uint32, routerID net.IP) error {
 	// Check if we should start.
 	if address != "" && asn > 0 && routerID != nil {
 		// Restore old address on failure.
-		revert.Add(func() { _ = s.start(oldAddress, oldASN, oldRouterID) })
+		reverter.Add(func() { _ = s.start(oldAddress, oldASN, oldRouterID) })
 
 		// Start the listener with the new address.
 		err = s.start(address, asn, routerID)
@@ -226,7 +222,7 @@ func (s *Server) configure(address string, asn uint32, routerID net.IP) error {
 	}
 
 	// All done.
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -332,9 +328,7 @@ func (s *Server) RemovePrefixByOwner(owner string) error {
 
 	// Make a copy of the paths dict to safely iterate (path removal mutates it).
 	paths := map[string]path{}
-	for pathUUID, path := range s.paths {
-		paths[pathUUID] = path
-	}
+	maps.Copy(paths, s.paths)
 
 	// Iterate through the paths and remove them from the server.
 	for pathUUID, path := range paths {
