@@ -5,6 +5,7 @@ package cluster
 import (
 	"context"
 	"database/sql"
+	"maps"
 
 	"github.com/lxc/incus/v6/internal/server/device/config"
 	"github.com/lxc/incus/v6/shared/api"
@@ -132,15 +133,11 @@ func ExpandInstanceConfig(config map[string]string, profiles []api.Profile) map[
 	}
 
 	for i := range profileConfigs {
-		for k, v := range profileConfigs[i] {
-			expandedConfig[k] = v
-		}
+		maps.Copy(expandedConfig, profileConfigs[i])
 	}
 
 	// Stick the given config on top
-	for k, v := range config {
-		expandedConfig[k] = v
-	}
+	maps.Copy(expandedConfig, config)
 
 	return expandedConfig
 }
@@ -157,15 +154,11 @@ func ExpandInstanceDevices(devices config.Devices, profiles []api.Profile) confi
 	}
 
 	for i := range profileDevices {
-		for k, v := range profileDevices[i] {
-			expandedDevices[k] = v
-		}
+		maps.Copy(expandedDevices, profileDevices[i])
 	}
 
 	// Stick the given devices on top
-	for k, v := range devices {
-		expandedDevices[k] = v
-	}
+	maps.Copy(expandedDevices, devices)
 
 	return expandedDevices
 }
