@@ -5,6 +5,7 @@ package db
 import (
 	"context"
 	"database/sql"
+	"errors"
 	"fmt"
 	"net/http"
 	"slices"
@@ -195,7 +196,7 @@ func (c *ClusterTx) GetNodeByAddress(ctx context.Context, address string) (NodeI
 	case 1:
 		return nodes[0], nil
 	default:
-		return null, fmt.Errorf("more than one node matches")
+		return null, errors.New("more than one node matches")
 	}
 }
 
@@ -239,7 +240,7 @@ func (c *ClusterTx) GetNodeWithID(ctx context.Context, nodeID int) (NodeInfo, er
 	case 1:
 		return nodes[0], nil
 	default:
-		return null, fmt.Errorf("More than one cluster member matches")
+		return null, errors.New("More than one cluster member matches")
 	}
 }
 
@@ -257,7 +258,25 @@ func (c *ClusterTx) GetPendingNodeByAddress(ctx context.Context, address string)
 	case 1:
 		return nodes[0], nil
 	default:
-		return null, fmt.Errorf("More than one cluster member matches")
+		return null, errors.New("More than one cluster member matches")
+	}
+}
+
+// GetPendingNodeByName returns the pending node with the given name.
+func (c *ClusterTx) GetPendingNodeByName(ctx context.Context, name string) (NodeInfo, error) {
+	null := NodeInfo{}
+	nodes, err := c.nodes(ctx, true /* pending */, "name=?", name)
+	if err != nil {
+		return null, err
+	}
+
+	switch len(nodes) {
+	case 0:
+		return null, api.StatusErrorf(http.StatusNotFound, "Cluster member not found")
+	case 1:
+		return nodes[0], nil
+	default:
+		return null, errors.New("More than one cluster member matches")
 	}
 }
 
@@ -275,7 +294,7 @@ func (c *ClusterTx) GetNodeByName(ctx context.Context, name string) (NodeInfo, e
 	case 1:
 		return nodes[0], nil
 	default:
-		return null, fmt.Errorf("More than one cluster member matches")
+		return null, errors.New("More than one cluster member matches")
 	}
 }
 
@@ -294,7 +313,7 @@ func (c *ClusterTx) GetLocalNodeName(ctx context.Context) (string, error) {
 	case 1:
 		return names[0], nil
 	default:
-		return "", fmt.Errorf("inconsistency: non-unique node ID")
+		return "", errors.New("inconsistency: non-unique node ID")
 	}
 }
 
@@ -312,7 +331,7 @@ func (c *ClusterTx) GetLocalNodeAddress(ctx context.Context) (string, error) {
 	case 1:
 		return addresses[0], nil
 	default:
-		return "", fmt.Errorf("inconsistency: non-unique node ID")
+		return "", errors.New("inconsistency: non-unique node ID")
 	}
 }
 
@@ -332,7 +351,7 @@ func (c *ClusterTx) NodeIsOutdated(ctx context.Context) (bool, error) {
 		}
 	}
 	if version[0] == 0 || version[1] == 0 {
-		return false, fmt.Errorf("Inconsistency: local member not found")
+		return false, errors.New("Inconsistency: local member not found")
 	}
 
 	// Check if any of the other nodes is greater than us.
@@ -718,7 +737,7 @@ func (c *ClusterTx) UpdateNodeFailureDomain(ctx context.Context, id int64, domai
 	var domainID any
 
 	if domain == "" {
-		return fmt.Errorf("Failure domain name can't be empty")
+		return errors.New("Failure domain name can't be empty")
 	}
 
 	if domain == "default" {
@@ -727,7 +746,7 @@ func (c *ClusterTx) UpdateNodeFailureDomain(ctx context.Context, id int64, domai
 		row := c.tx.QueryRowContext(ctx, "SELECT id FROM nodes_failure_domains WHERE name=?", domain)
 		err := row.Scan(&domainID)
 		if err != nil {
-			if err != sql.ErrNoRows {
+			if !errors.Is(err, sql.ErrNoRows) {
 				return fmt.Errorf("Load failure domain name: %w", err)
 			}
 
@@ -1161,7 +1180,7 @@ func (c *ClusterTx) SetNodeVersion(id int64, version [2]int) error {
 	}
 
 	if n != 1 {
-		return fmt.Errorf("Expected exactly one row to be updated")
+		return errors.New("Expected exactly one row to be updated")
 	}
 
 	return nil
