@@ -62,7 +62,7 @@ func (e *Endpoints) ClusterUpdateAddress(address string) error {
 		var err error
 		var listener net.Listener
 
-		for i := 0; i < 10; i++ { // Ten retries over a second seems reasonable.
+		for range 10 { // Ten retries over a second seems reasonable.
 			listener, err = net.Listen("tcp", address)
 			if err == nil {
 				break
@@ -78,23 +78,21 @@ func (e *Endpoints) ClusterUpdateAddress(address string) error {
 		return &listener, nil
 	}
 
-	// If setting a new address, setup the listener
-	if address != "" {
-		listener, err := getListener(address)
-		if err != nil {
-			// Attempt to revert to the previous address
-			listener, err1 := getListener(oldAddress)
-			if err1 == nil {
-				e.listeners[cluster] = listeners.NewFancyTLSListener(*listener, e.cert)
-				e.serve(cluster)
-			}
-
-			return err
+	// set up the listener
+	listener, err := getListener(address)
+	if err != nil {
+		// Attempt to revert to the previous address
+		listener, err1 := getListener(oldAddress)
+		if err1 == nil {
+			e.listeners[cluster] = listeners.NewFancyTLSListener(*listener, e.cert)
+			e.serve(cluster)
 		}
 
-		e.listeners[cluster] = listeners.NewFancyTLSListener(*listener, e.cert)
-		e.serve(cluster)
+		return err
 	}
 
+	e.listeners[cluster] = listeners.NewFancyTLSListener(*listener, e.cert)
+	e.serve(cluster)
+
 	return nil
 }
