@@ -3,6 +3,7 @@ package drivers
 import (
 	"bufio"
 	"encoding/hex"
+	"errors"
 	"fmt"
 	"net"
 	"os"
@@ -124,13 +125,7 @@ func (d Xtables) iptablesInUse(iptablesCmd string) bool {
 		return false
 	}
 
-	for _, table := range []string{"filter", "nat", "mangle", "raw"} {
-		if tableIsUse(table) {
-			return true
-		}
-	}
-
-	return false
+	return slices.ContainsFunc([]string{"filter", "nat", "mangle", "raw"}, tableIsUse)
 }
 
 // ebtablesInUse returns whether the ebtables backend command has any rules defined.
@@ -417,7 +412,7 @@ func (d Xtables) networkSetupICMPDHCPDNSAccess(networkName string, ipVersion uin
 			rules = append(rules, []string{"6", networkName, "filter", "OUTPUT", "-o", networkName, "-p", "icmpv6", "-m", "icmp6", "--icmpv6-type", fmt.Sprintf("%d", icmpType), "-j", "ACCEPT"})
 		}
 	} else {
-		return fmt.Errorf("Invalid IP version")
+		return errors.New("Invalid IP version")
 	}
 
 	comment := d.networkIPTablesComment(networkName)
@@ -662,7 +657,7 @@ func (d Xtables) aclRuleCriteriaToArgs(networkName string, ipVersion uint, rule
 		}
 
 		if rule.ICMPCode != "" && rule.ICMPType == "" {
-			return nil, nil, fmt.Errorf("Invalid use of ICMP code without ICMP type")
+			return nil, nil, errors.New("Invalid use of ICMP code without ICMP type")
 		}
 
 		args = append(args, "-p", protoName)
@@ -811,9 +806,9 @@ func (d Xtables) instanceDeviceIPTablesComment(projectName string, instanceName
 // If the parent bridge is managed by Incus then parentManaged argument should be true so that the rules added can
 // use the iptablesChainACLFilterPrefix chain. If not they are added to the main filter chains directly (which only
 // works for unmanaged bridges because those don't support ACLs).
-func (d Xtables) InstanceSetupBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet, parentManaged bool, macFiltering bool, aclRules []ACLRule) error {
+func (d Xtables) InstanceSetupBridgeFilter(projectName string, instanceName string, deviceName string, parentName string, hostName string, hwAddr string, IPv4Nets []*net.IPNet, IPv6Nets []*net.IPNet, IPv4DNS []string, IPv6DNS []string, parentManaged bool, macFiltering bool, aclRules []ACLRule) error {
 	if len(aclRules) > 0 {
-		return fmt.Errorf("ACL rules not supported for xtables bridge filtering")
+		return errors.New("ACL rules not supported for xtables bridge filtering")
 	}
 
 	comment := d.instanceDeviceIPTablesComment(projectName, instanceName, deviceName)
@@ -911,22 +906,22 @@ func (d Xtables) InstanceClearBridgeFilter(projectName string, instanceName stri
 // InstanceSetupProxyNAT creates DNAT rules for proxy devices.
 func (d Xtables) InstanceSetupProxyNAT(projectName string, instanceName string, deviceName string, forward *AddressForward) error {
 	if forward.ListenAddress == nil {
-		return fmt.Errorf("Listen address is required")
+		return errors.New("Listen address is required")
 	}
 
 	if forward.TargetAddress == nil {
-		return fmt.Errorf("Target address is required")
+		return errors.New("Target address is required")
 	}
 
 	listenPortsLen := len(forward.ListenPorts)
 	if listenPortsLen <= 0 {
-		return fmt.Errorf("At least 1 listen port must be supplied")
+		return errors.New("At least 1 listen port must be supplied")
 	}
 
 	// If multiple target ports supplied, check they match the listen port(s) count.
 	targetPortsLen := len(forward.TargetPorts)
 	if targetPortsLen != 1 && targetPortsLen != listenPortsLen {
-		return fmt.Errorf("Mismatch between listen port(s) and target port(s) count")
+		return errors.New("Mismatch between listen port(s) and target port(s) count")
 	}
 
 	ipVersion := uint(4)
@@ -937,9 +932,10 @@ func (d Xtables) InstanceSetupProxyNAT(projectName string, instanceName string,
 	listenAddressStr := forward.ListenAddress.String()
 	targetAddressStr := forward.TargetAddress.String()
 
-	revert := revert.New()
-	defer revert.Fail()
-	revert.Add(func() { _ = d.InstanceClearProxyNAT(projectName, instanceName, deviceName) })
+	reverter := revert.New()
+	defer reverter.Fail()
+
+	reverter.Add(func() { _ = d.InstanceClearProxyNAT(projectName, instanceName, deviceName) })
 
 	comment := d.instanceDeviceIPTablesComment(projectName, instanceName, deviceName)
 
@@ -982,7 +978,8 @@ func (d Xtables) InstanceSetupProxyNAT(projectName string, instanceName string,
 		}
 	}
 
-	revert.Success()
+	reverter.Success()
+
 	return nil
 }
 
@@ -1223,7 +1220,7 @@ func (d Xtables) iptablesAdd(ipVersion uint, comment string, table string, metho
 	} else if ipVersion == 6 {
 		cmd = "ip6tables"
 	} else {
-		return fmt.Errorf("Invalid IP version")
+		return errors.New("Invalid IP version")
 	}
 
 	_, err := exec.LookPath(cmd)
@@ -1264,7 +1261,7 @@ func (d Xtables) iptablesClear(ipVersion uint, comments []string, fromTables ...
 		cmd = "ip6tables"
 		tablesFile = "/proc/self/net/ip6_tables_names"
 	} else {
-		return fmt.Errorf("Invalid IP version")
+		return errors.New("Invalid IP version")
 	}
 
 	// Detect kernels that lack IPv6 support.
@@ -1437,7 +1434,7 @@ func (d Xtables) iptablesChainExists(ipVersion uint, table string, chain string)
 	} else if ipVersion == 6 {
 		cmd = "ip6tables"
 	} else {
-		return false, false, fmt.Errorf("Invalid IP version")
+		return false, false, errors.New("Invalid IP version")
 	}
 
 	_, err := exec.LookPath(cmd)
@@ -1468,7 +1465,7 @@ func (d Xtables) iptablesChainCreate(ipVersion uint, table string, chain string)
 	} else if ipVersion == 6 {
 		cmd = "ip6tables"
 	} else {
-		return fmt.Errorf("Invalid IP version")
+		return errors.New("Invalid IP version")
 	}
 
 	// Attempt to create chain in table.
@@ -1488,7 +1485,7 @@ func (d Xtables) iptablesChainDelete(ipVersion uint, table string, chain string,
 	} else if ipVersion == 6 {
 		cmd = "ip6tables"
 	} else {
-		return fmt.Errorf("Invalid IP version")
+		return errors.New("Invalid IP version")
 	}
 
 	// Attempt to flush rules from chain in table.
@@ -1580,6 +1577,11 @@ func (d Xtables) NetworkApplyForwards(networkName string, rules []AddressForward
 			targetAddressStr := rule.TargetAddress.String()
 
 			if rule.Protocol != "" {
+				// We don't support SNAT here yet.
+				if rule.SNAT {
+					return errors.New("SNAT port rules are not supported under xtables")
+				}
+
 				if len(rule.TargetPorts) == 0 {
 					rule.TargetPorts = rule.ListenPorts
 				}
@@ -1653,5 +1655,6 @@ func (d Xtables) NetworkApplyForwards(networkName string, rules []AddressForward
 	}
 
 	reverter.Success()
+
 	return nil
 }
