@@ -3,6 +3,7 @@ package qmp
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"net"
 	"net/http"
@@ -74,6 +75,68 @@ type CPUModel struct {
 	Flags map[string]any `json:"props"`
 }
 
+// MemoryDevice contains information about a memory device.
+type MemoryDevice struct {
+	Type string          `json:"type"`
+	Data json.RawMessage `json:"data"`
+}
+
+// PCDimmDevice contains information about a memory device of type pc-dimm.
+type PCDimmDevice struct {
+	ID           string `json:"id"`
+	Addr         uint64 `json:"addr"`
+	Slot         int    `json:"slot"`
+	Node         int    `json:"node"`
+	Memdev       string `json:"memdev"`
+	Hotpluggable bool   `json:"hotpluggable"`
+	Hotplugged   bool   `json:"hotplugged"`
+}
+
+// MemDev contains information about a memory device.
+type MemDev struct {
+	ID        string `json:"id"`
+	Size      int    `json:"size"`
+	Merge     bool   `json:"merge"`
+	Dump      bool   `json:"dump"`
+	Prealloc  bool   `json:"prealloc"`
+	Share     bool   `json:"share"`
+	Reserve   bool   `json:"reserve"`
+	HostNodes []int  `json:"host-nodes"`
+}
+
+// MigrationStatus contains information about the ongoing migration.
+type MigrationStatus struct {
+	Status string `json:"status"`
+	RAM    struct {
+		Transferred             int64   `json:"transferred"`
+		Remaining               int64   `json:"remaining"`
+		Total                   int64   `json:"total"`
+		Duplicate               int64   `json:"duplicate"`
+		Normal                  int64   `json:"normal"`
+		NormalBytes             int64   `json:"normal-bytes"`
+		DirtyPagesRate          int64   `json:"diry-pages-rate"`
+		MBps                    float64 `json:"mbps"`
+		DirtySyncCount          int64   `json:"diry-sync-count"`
+		PostcopyRequests        int64   `json:"postcopy-requests"`
+		PageSize                int64   `json:"page-size"`
+		MultiFDBytes            int64   `json:"multifd-bytes"`
+		PagesPerSecond          int64   `json:"pages-per-second"`
+		PrecopyBytes            int64   `json:"precopy-bytes"`
+		DowntimeBytes           int64   `json:"downtime-bytes"`
+		PostcopyBytes           int64   `json:"postcopy-bytes"`
+		DirtySyncMissedZeroCopy int64   `json:"diry-sync-missed-zero-copy"`
+	} `json:"ram"`
+	TotalTime                      int64   `json:"total-time"`
+	DownTime                       int64   `json:"down-time"`
+	ExpectedDowntime               int64   `json:"expected-downtime"`
+	SetupTime                      int64   `json:"setup-time"`
+	CPUThrottlePercentage          int64   `json:"cpu-throttle-percentage"`
+	PostcopyBlocktime              int64   `json:"postcopy-blocktime"`
+	PostcopyVCPUBlocktime          []int64 `json:"postcopy-vcpu-blocktime"`
+	DirtyLimitThrottleTimePerRound int64   `json:"dirty-limit-throttle-time-per-round"`
+	DirtyLimitRingFullTime         int64   `json:"dirty-limit-ring-full-time"`
+}
+
 // QueryCPUs returns a list of CPUs.
 func (m *Monitor) QueryCPUs() ([]CPU, error) {
 	// Prepare the response.
@@ -176,23 +239,20 @@ func (m *Monitor) SendFile(name string, file *os.File) error {
 		return ErrMonitorDisconnect
 	}
 
-	var req struct {
-		Execute   string `json:"execute"`
-		Arguments struct {
-			FDName string `json:"fdname"`
-		} `json:"arguments"`
+	id := m.qmp.qmpIncreaseID()
+	req := &qmpCommand{
+		ID:        id,
+		Execute:   "getfd",
+		Arguments: map[string]any{"fdname": name},
 	}
 
-	req.Execute = "getfd"
-	req.Arguments.FDName = name
-
 	reqJSON, err := json.Marshal(req)
 	if err != nil {
 		return err
 	}
 
 	// Query the status.
-	_, err = m.qmp.RunWithFile(reqJSON, file)
+	_, err = m.qmp.runWithFile(reqJSON, file, id)
 	if err != nil {
 		// Confirm the daemon didn't die.
 		errPing := m.ping()
@@ -229,27 +289,26 @@ func (m *Monitor) SendFileWithFDSet(name string, file *os.File, readonly bool) (
 		return nil, ErrMonitorDisconnect
 	}
 
-	var req struct {
-		Execute   string `json:"execute"`
-		Arguments struct {
-			Opaque string `json:"opaque"`
-		} `json:"arguments"`
-	}
-
 	permissions := "rdwr"
 	if readonly {
 		permissions = "rdonly"
 	}
 
-	req.Execute = "add-fd"
-	req.Arguments.Opaque = fmt.Sprintf("%s:%s", permissions, name)
+	id := m.qmp.qmpIncreaseID()
+	req := &qmpCommand{
+		ID:      id,
+		Execute: "add-fd",
+		Arguments: map[string]any{
+			"opaque": fmt.Sprintf("%s:%s", permissions, name),
+		},
+	}
 
 	reqJSON, err := json.Marshal(req)
 	if err != nil {
 		return nil, err
 	}
 
-	ret, err := m.qmp.RunWithFile(reqJSON, file)
+	ret, err := m.qmp.runWithFile(reqJSON, file, id)
 	if err != nil {
 		// Confirm the daemon didn't die.
 		errPing := m.ping()
@@ -339,6 +398,16 @@ func (m *Monitor) MigrateSetCapabilities(caps map[string]bool) error {
 	return nil
 }
 
+// MigrateSetParameters sets the parameters used during migration.
+func (m *Monitor) MigrateSetParameters(parameters map[string]any) error {
+	err := m.Run("migrate-set-parameters", parameters, nil)
+	if err != nil {
+		return err
+	}
+
+	return nil
+}
+
 // Migrate starts a migration stream.
 func (m *Monitor) Migrate(name string) error {
 	// Query the status.
@@ -370,6 +439,20 @@ func (m *Monitor) Migrate(name string) error {
 	return nil
 }
 
+// QueryMigrate gets the current migration status.
+func (m *Monitor) QueryMigrate() (*MigrationStatus, error) {
+	var resp struct {
+		Return MigrationStatus `json:"return"`
+	}
+
+	err := m.Run("query-migrate", nil, &resp)
+	if err != nil {
+		return nil, err
+	}
+
+	return &resp.Return, nil
+}
+
 // MigrateWait waits until migration job reaches the specified status.
 // Returns nil if the migraton job reaches the specified status or an error if the migration job is in the failed
 // status.
@@ -389,7 +472,7 @@ func (m *Monitor) MigrateWait(state string) error {
 		}
 
 		if resp.Return.Status == "failed" {
-			return fmt.Errorf("Migrate call failed")
+			return errors.New("Migrate call failed")
 		}
 
 		if resp.Return.Status == state {
@@ -458,7 +541,7 @@ func (m *Monitor) MigrateIncoming(ctx context.Context, name string) error {
 		}
 
 		if resp.Return.Status == "failed" {
-			return fmt.Errorf("Migrate incoming call failed")
+			return errors.New("Migrate incoming call failed")
 		}
 
 		if resp.Return.Status == "completed" {
@@ -562,14 +645,83 @@ func (m *Monitor) SetMemoryBalloonSizeBytes(sizeBytes int64) error {
 	return m.Run("balloon", args, nil)
 }
 
+// GetMemdev retrieves memory devices by executing the query-memdev QMP command.
+func (m *Monitor) GetMemdev() ([]MemDev, error) {
+	// Prepare the response.
+	var resp struct {
+		Return []MemDev `json:"return"`
+	}
+
+	err := m.Run("query-memdev", nil, &resp)
+	if err != nil {
+		return nil, err
+	}
+
+	return resp.Return, nil
+}
+
+// GetMemoryDevices retrieves memory devices by executing the query-memory-devices QMP command.
+func (m *Monitor) GetMemoryDevices() ([]MemoryDevice, error) {
+	// Prepare the response.
+	var resp struct {
+		Return []MemoryDevice `json:"return"`
+	}
+
+	err := m.Run("query-memory-devices", nil, &resp)
+	if err != nil {
+		return nil, err
+	}
+
+	return resp.Return, nil
+}
+
+// GetDimmDevices returns a list of memory devices of type pc-dimm.
+func (m *Monitor) GetDimmDevices() ([]PCDimmDevice, error) {
+	devices, err := m.GetMemoryDevices()
+	if err != nil {
+		return nil, err
+	}
+
+	result := []PCDimmDevice{}
+	for _, dev := range devices {
+		if dev.Type != "dimm" {
+			continue
+		}
+
+		var dimmData PCDimmDevice
+		err := json.Unmarshal(dev.Data, &dimmData)
+		if err != nil {
+			continue
+		}
+
+		result = append(result, dimmData)
+	}
+
+	return result, nil
+}
+
+// AddObject adds a new object.
+func (m *Monitor) AddObject(args map[string]any) error {
+	err := m.Run("object-add", &args, nil)
+	if err != nil {
+		return fmt.Errorf("Failed adding object: %w", err)
+	}
+
+	return nil
+}
+
 // AddBlockDevice adds a block device.
-func (m *Monitor) AddBlockDevice(blockDev map[string]any, device map[string]any) error {
-	revert := revert.New()
-	defer revert.Fail()
+func (m *Monitor) AddBlockDevice(blockDev map[string]any, device map[string]any, attached bool) error {
+	if !attached {
+		return nil
+	}
+
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	nodeName, ok := blockDev["node-name"].(string)
 	if !ok {
-		return fmt.Errorf("Device node name must be a string")
+		return errors.New("Device node name must be a string")
 	}
 
 	if blockDev != nil {
@@ -578,7 +730,7 @@ func (m *Monitor) AddBlockDevice(blockDev map[string]any, device map[string]any)
 			return fmt.Errorf("Failed adding block device: %w", err)
 		}
 
-		revert.Add(func() {
+		reverter.Add(func() {
 			_ = m.RemoveBlockDevice(nodeName)
 		})
 	}
@@ -588,7 +740,8 @@ func (m *Monitor) AddBlockDevice(blockDev map[string]any, device map[string]any)
 		return fmt.Errorf("Failed adding device: %w", err)
 	}
 
-	revert.Success()
+	reverter.Success()
+
 	return nil
 }
 
@@ -602,7 +755,7 @@ func (m *Monitor) RemoveBlockDevice(blockDevName string) error {
 		err := m.Run("blockdev-del", blockDevName, nil)
 		if err != nil {
 			if strings.Contains(err.Error(), "is in use") {
-				return api.StatusErrorf(http.StatusLocked, err.Error())
+				return api.StatusErrorf(http.StatusLocked, "%s", err.Error())
 			}
 
 			if strings.Contains(err.Error(), "Failed to find") {
@@ -682,8 +835,8 @@ func (m *Monitor) RemoveDevice(deviceID string) error {
 
 // AddNIC adds a NIC device.
 func (m *Monitor) AddNIC(netDev map[string]any, device map[string]any) error {
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	if netDev != nil {
 		err := m.Run("netdev_add", netDev, nil)
@@ -691,7 +844,7 @@ func (m *Monitor) AddNIC(netDev map[string]any, device map[string]any) error {
 			return fmt.Errorf("Failed adding NIC netdev: %w", err)
 		}
 
-		revert.Add(func() {
+		reverter.Add(func() {
 			netDevDel := map[string]any{
 				"id": netDev["id"],
 			}
@@ -708,7 +861,8 @@ func (m *Monitor) AddNIC(netDev map[string]any, device map[string]any) error {
 		return fmt.Errorf("Failed adding NIC device: %w", err)
 	}
 
-	revert.Success()
+	reverter.Success()
+
 	return nil
 }
 
@@ -994,7 +1148,7 @@ func (m *Monitor) blockJobWaitReady(jobID string) error {
 		}
 
 		if !found {
-			return fmt.Errorf("Specified block job not found")
+			return errors.New("Specified block job not found")
 		}
 
 		time.Sleep(1 * time.Second)
@@ -1096,22 +1250,6 @@ func (m *Monitor) BlockJobComplete(deviceNodeName string) error {
 	return nil
 }
 
-// Eject ejects a removable drive.
-func (m *Monitor) Eject(id string) error {
-	var args struct {
-		ID string `json:"id"`
-	}
-
-	args.ID = id
-
-	err := m.Run("eject", args, nil)
-	if err != nil {
-		return err
-	}
-
-	return nil
-}
-
 // UpdateBlockSize updates the size of a disk.
 func (m *Monitor) UpdateBlockSize(id string) error {
 	var args struct {
@@ -1191,7 +1329,7 @@ func (m *Monitor) RingbufRead(device string) (string, error) {
 		return "", err
 	}
 
-	deviceFound := true
+	deviceFound := false
 	for _, qemuDevice := range queryResp.Return {
 		if qemuDevice.Label == device {
 			deviceFound = true
@@ -1203,6 +1341,7 @@ func (m *Monitor) RingbufRead(device string) (string, error) {
 			break
 		}
 	}
+
 	if !deviceFound {
 		return "", fmt.Errorf("Specified qemu device %q doesn't exist", device)
 	}
