@@ -50,7 +50,7 @@ func (m *MetricSet) FilterSamples(permissionChecker func(object auth.Object) boo
 
 // AddSamples adds samples of the type metricType to the MetricSet.
 func (m *MetricSet) AddSamples(metricType MetricType, samples ...Sample) {
-	for i := 0; i < len(samples); i++ {
+	for i := range samples {
 		// Add global labels to samples
 		for labelName, labelValue := range m.labels {
 			// Ensure we always have a valid Labels map
@@ -65,6 +65,11 @@ func (m *MetricSet) AddSamples(metricType MetricType, samples ...Sample) {
 	m.set[metricType] = append(m.set[metricType], samples...)
 }
 
+// AddRaw allows for adding extra metrics directly to the output without having to parse them first.
+func (m *MetricSet) AddRaw(rawData []byte) {
+	m.suffix = append(m.suffix, rawData...)
+}
+
 // Merge merges two MetricSets. Missing labels from m's samples are added to all samples in n.
 func (m *MetricSet) Merge(metricSet *MetricSet) {
 	if metricSet == nil {
@@ -84,6 +89,10 @@ func (m *MetricSet) Merge(metricSet *MetricSet) {
 			m.set[metricType] = append(m.set[metricType], sample)
 		}
 	}
+
+	if metricSet.suffix != nil {
+		m.suffix = append(m.suffix, metricSet.suffix...)
+	}
 }
 
 func (m *MetricSet) String() string {
@@ -158,7 +167,12 @@ func (m *MetricSet) String() string {
 		}
 	}
 
-	_, err := out.WriteString("# EOF\n")
+	_, err := out.Write(m.suffix)
+	if err != nil {
+		return ""
+	}
+
+	_, err = out.WriteString("# EOF\n")
 	if err != nil {
 		return ""
 	}
