@@ -15,6 +15,9 @@ import (
 // separator is used to delimit the project name from the suffix.
 const separator = "_"
 
+// projectLimitDiskPool is the prefix used for pool-specific disk limits.
+var projectLimitDiskPool = "limits.disk.pool."
+
 // Instance adds the "<project>_" prefix to instance name when the given project name is not "default".
 func Instance(projectName string, instanceName string) string {
 	if projectName != api.ProjectDefaultName {
@@ -59,6 +62,12 @@ func StorageVolume(projectName string, storageVolumeName string) string {
 // name as separate variables.
 func StorageVolumeParts(projectStorageVolumeName string) (string, string) {
 	parts := strings.SplitN(projectStorageVolumeName, "_", 2)
+
+	// If the given name doesn't contain any project, only return the volume name.
+	if len(parts) == 1 {
+		return "", projectStorageVolumeName
+	}
+
 	return parts[0], parts[1]
 }
 
@@ -74,11 +83,6 @@ func StorageVolumeProject(c *db.Cluster, projectName string, volumeType int) (st
 		return api.ProjectDefaultName, nil
 	}
 
-	// Non-custom volumes always use the project specified. Optimisation to avoid loading project record.
-	if volumeType != db.StoragePoolVolumeTypeCustom {
-		return projectName, nil
-	}
-
 	var project *api.Project
 	err := c.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
 		dbProject, err := cluster.GetProject(ctx, tx.Tx(), projectName)
