@@ -2,6 +2,7 @@ package scriptlet
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	"go.starlark.net/starlark"
@@ -10,14 +11,14 @@ import (
 	"github.com/lxc/incus/v6/internal/server/db"
 	dbCluster "github.com/lxc/incus/v6/internal/server/db/cluster"
 	internalInstance "github.com/lxc/incus/v6/internal/server/instance"
-	"github.com/lxc/incus/v6/internal/server/resources"
 	scriptletLoad "github.com/lxc/incus/v6/internal/server/scriptlet/load"
 	"github.com/lxc/incus/v6/internal/server/scriptlet/log"
-	"github.com/lxc/incus/v6/internal/server/scriptlet/marshal"
 	"github.com/lxc/incus/v6/internal/server/state"
 	"github.com/lxc/incus/v6/shared/api"
 	apiScriptlet "github.com/lxc/incus/v6/shared/api/scriptlet"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/resources"
+	"github.com/lxc/incus/v6/shared/scriptlet"
 )
 
 // InstancePlacementRun runs the instance placement scriptlet and returns the chosen cluster member target.
@@ -46,7 +47,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 
 		if targetMember == nil {
 			l.Error("Instance placement scriptlet set invalid member target", logger.Ctx{"member": memberName})
-			return starlark.String("Invalid member name"), fmt.Errorf("Invalid member name: %s", memberName)
+			return nil, fmt.Errorf("Invalid member name: %s", memberName)
 		}
 
 		l.Info("Instance placement scriptlet set member target", logger.Ctx{"member": targetMember.Name})
@@ -81,7 +82,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			}
 
 			if targetMember == nil {
-				return starlark.String("Invalid member name"), nil
+				return nil, fmt.Errorf("Invalid member name: %s", memberName)
 			}
 
 			client, err := cluster.Connect(targetMember.Address, s.Endpoints.NetworkCert(), s.ServerCert(), nil, true)
@@ -95,7 +96,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			}
 		}
 
-		rv, err := marshal.StarlarkMarshal(res)
+		rv, err := scriptlet.StarlarkMarshal(res)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling cluster member resources for %q failed: %w", memberName, err)
 		}
@@ -130,7 +131,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			}
 
 			if targetMember == nil {
-				return starlark.String("Invalid member name"), nil
+				return nil, fmt.Errorf("Invalid member name: %s", memberName)
 			}
 
 			client, err := cluster.Connect(targetMember.Address, s.Endpoints.NetworkCert(), s.ServerCert(), nil, true)
@@ -144,7 +145,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			}
 		}
 
-		rv, err := marshal.StarlarkMarshal(memberState)
+		rv, err := scriptlet.StarlarkMarshal(memberState)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling cluster member state for %q failed: %w", memberName, err)
 		}
@@ -165,7 +166,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 		res.MemorySize = uint64(usageMemory)
 		res.RootDiskSize = uint64(usageDisk)
 
-		rv, err := marshal.StarlarkMarshal(res)
+		rv, err := scriptlet.StarlarkMarshal(res)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling instance resources failed: %w", err)
 		}
@@ -233,7 +234,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(instanceList)
+		rv, err := scriptlet.StarlarkMarshal(instanceList)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling instances failed: %w", err)
 		}
@@ -261,7 +262,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(count)
+		rv, err := scriptlet.StarlarkMarshal(count)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling instance count failed: %w", err)
 		}
@@ -349,7 +350,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(allMembersInfo)
+		rv, err := scriptlet.StarlarkMarshal(allMembersInfo)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling cluster members failed: %w", err)
 		}
@@ -384,7 +385,7 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(p)
+		rv, err := scriptlet.StarlarkMarshal(p)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling project failed: %w", err)
 		}
@@ -483,15 +484,15 @@ func InstancePlacementRun(ctx context.Context, l logger.Logger, s *state.State,
 	// Retrieve a global variable from starlark environment.
 	instancePlacement := globals["instance_placement"]
 	if instancePlacement == nil {
-		return nil, fmt.Errorf("Scriptlet missing instance_placement function")
+		return nil, errors.New("Scriptlet missing instance_placement function")
 	}
 
-	rv, err := marshal.StarlarkMarshal(req)
+	rv, err := scriptlet.StarlarkMarshal(req)
 	if err != nil {
 		return nil, fmt.Errorf("Marshalling request failed: %w", err)
 	}
 
-	candidateMembersv, err := marshal.StarlarkMarshal(candidateMembersInfo)
+	candidateMembersv, err := scriptlet.StarlarkMarshal(candidateMembersInfo)
 	if err != nil {
 		return nil, fmt.Errorf("Marshalling candidate members failed: %w", err)
 	}
