@@ -12,20 +12,11 @@ import (
 	"github.com/lxc/incus/v6/internal/server/instance/drivers/qmp"
 	scriptletLoad "github.com/lxc/incus/v6/internal/server/scriptlet/load"
 	"github.com/lxc/incus/v6/internal/server/scriptlet/log"
-	"github.com/lxc/incus/v6/internal/server/scriptlet/marshal"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/scriptlet"
 )
 
-// qemuCfgSection is a temporary struct to hold QEMU configuration sections with Entries of type
-// map[string]string instead of []cfg.Entry. This type should be moved to the cfg package in the
-// future.
-type qemuCfgSection struct {
-	Name    string            `json:"name"`
-	Comment string            `json:"comment"`
-	Entries map[string]string `json:"entries"`
-}
-
 // marshalQEMUConf marshals a configuration into a []map[string]any.
 func marshalQEMUConf(conf any) ([]map[string]any, error) {
 	jsonConf, err := json.Marshal(conf)
@@ -42,14 +33,14 @@ func marshalQEMUConf(conf any) ([]map[string]any, error) {
 	return newConf, nil
 }
 
-// unmarshalQEMUConf unmarshals a configuration into a []qemuCfgSection.
-func unmarshalQEMUConf(conf any) ([]qemuCfgSection, error) {
+// unmarshalQEMUConf unmarshals a configuration into a []cfg.Section.
+func unmarshalQEMUConf(conf any) ([]cfg.Section, error) {
 	jsonConf, err := json.Marshal(conf)
 	if err != nil {
 		return nil, err
 	}
 
-	var newConf []qemuCfgSection
+	var newConf []cfg.Section
 	err = json.Unmarshal(jsonConf, &newConf)
 	if err != nil {
 		return nil, err
@@ -62,19 +53,8 @@ func unmarshalQEMUConf(conf any) ([]qemuCfgSection, error) {
 func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[]cfg.Section, m *qmp.Monitor, stage string) error {
 	logFunc := log.CreateLogger(l, "QEMU scriptlet ("+stage+")")
 
-	// We first convert from []cfg.Section to []qemuCfgSection. This conversion is temporary.
-	var cfgSectionMaps []qemuCfgSection
-	for _, section := range *conf {
-		entries := map[string]string{}
-		for _, entry := range section.Entries {
-			entries[entry.Key] = entry.Value
-		}
-
-		cfgSectionMaps = append(cfgSectionMaps, qemuCfgSection{Name: section.Name, Comment: section.Comment, Entries: entries})
-	}
-
 	// We do not want to handle a qemuCfgSection object within our scriptlet, for simplicity.
-	cfgSections, err := marshalQEMUConf(cfgSectionMaps)
+	cfgSections, err := marshalQEMUConf(conf)
 	if err != nil {
 		return err
 	}
@@ -107,23 +87,31 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 			return nil, err
 		}
 
-		value, err := marshal.StarlarkUnmarshal(command)
+		value, err := scriptlet.StarlarkUnmarshal(command)
 		if err != nil {
 			return nil, err
 		}
 
+		id := uint32(0)
+		req, ok := value.(map[string]any)
+		if ok {
+			id = m.IncreaseID()
+			req["id"] = id
+			value = req
+		}
+
 		request, err := json.Marshal(value)
 		if err != nil {
 			return nil, err
 		}
 
 		var resp map[string]any
-		err = m.RunJSON(request, &resp, true)
+		err = m.RunJSON(request, &resp, true, id)
 		if err != nil {
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(resp)
+		rv, err := scriptlet.StarlarkMarshal(resp)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling QMP response failed: %w", err)
 		}
@@ -134,12 +122,12 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 	runCommandFromKwargs := func(funName string, kwargs []starlark.Tuple) (starlark.Value, error) {
 		qmpArgs := make(map[string]any)
 		for _, kwarg := range kwargs {
-			key, err := marshal.StarlarkUnmarshal(kwarg.Index(0))
+			key, err := scriptlet.StarlarkUnmarshal(kwarg.Index(0))
 			if err != nil {
 				return nil, err
 			}
 
-			value, err := marshal.StarlarkUnmarshal(kwarg.Index(1))
+			value, err := scriptlet.StarlarkUnmarshal(kwarg.Index(1))
 			if err != nil {
 				return nil, err
 			}
@@ -157,7 +145,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 		}
 
 		// Extract the return value
-		rv, err := marshal.StarlarkMarshal(resp.Return)
+		rv, err := scriptlet.StarlarkMarshal(resp.Return)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling QMP response failed: %w", err)
 		}
@@ -179,7 +167,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 			return nil, fmt.Errorf("%s Expected exactly one positional argument, got %d", errPrefix, argsLen)
 		}
 
-		arg, err := marshal.StarlarkUnmarshal(args.Index(0))
+		arg, err := scriptlet.StarlarkUnmarshal(args.Index(0))
 		if err != nil {
 			return nil, err
 		}
@@ -229,7 +217,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(cmdArgs)
+		rv, err := scriptlet.StarlarkMarshal(cmdArgs)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling QEMU command-line arguments failed: %w", err)
 		}
@@ -249,7 +237,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 			return nil, err
 		}
 
-		newCmdArgsAny, err := marshal.StarlarkUnmarshal(newCmdArgsv)
+		newCmdArgsAny, err := scriptlet.StarlarkUnmarshal(newCmdArgsv)
 		if err != nil {
 			return nil, err
 		}
@@ -306,7 +294,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 			return nil, err
 		}
 
-		rv, err := marshal.StarlarkMarshal(cfgSections)
+		rv, err := scriptlet.StarlarkMarshal(cfgSections)
 		if err != nil {
 			return nil, fmt.Errorf("Marshalling QEMU configuration failed: %w", err)
 		}
@@ -326,7 +314,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 			return nil, err
 		}
 
-		confAny, err := marshal.StarlarkUnmarshal(newConf)
+		confAny, err := scriptlet.StarlarkUnmarshal(newConf)
 		if err != nil {
 			return nil, err
 		}
@@ -347,7 +335,7 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 		}
 
 		// We want to further check the configuration structure, by trying to unmarshal it to a
-		// []qemuCfgSection.
+		// []cfg.Section.
 		_, err = unmarshalQEMUConf(confAny)
 		if err != nil {
 			return nil, fmt.Errorf("%s requires a valid configuration", b.Name())
@@ -402,10 +390,10 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 	// Retrieve a global variable from starlark environment.
 	qemuHook := globals["qemu_hook"]
 	if qemuHook == nil {
-		return fmt.Errorf("Scriptlet missing qemu_hook function")
+		return errors.New("Scriptlet missing qemu_hook function")
 	}
 
-	instancev, err := marshal.StarlarkMarshal(instance)
+	instancev, err := scriptlet.StarlarkMarshal(instance)
 	if err != nil {
 		return fmt.Errorf("Marshalling instance failed: %w", err)
 	}
@@ -430,23 +418,10 @@ func QEMURun(l logger.Logger, instance *api.Instance, cmdArgs *[]string, conf *[
 	}
 
 	// We need to convert the configuration back to a suitable format
-	cfgSectionMaps, err = unmarshalQEMUConf(cfgSections)
+	*conf, err = unmarshalQEMUConf(cfgSections)
 	if err != nil {
 		return err
 	}
 
-	// We convert back from []qemuCfgSection to []cfg.Section. This conversion is temporary.
-	var newConf []cfg.Section
-	for _, section := range cfgSectionMaps {
-		entries := []cfg.Entry{}
-		for key, value := range section.Entries {
-			entries = append(entries, cfg.Entry{Key: key, Value: value})
-		}
-
-		newConf = append(newConf, cfg.Section{Name: section.Name, Comment: section.Comment, Entries: entries})
-	}
-
-	*conf = newConf
-
 	return nil
 }
