@@ -29,6 +29,8 @@ import (
 
 const lvmVgPoolMarker = "incus_pool" // Indicator tag used to mark volume groups as in use.
 
+var lvmActivation sync.Mutex
+
 var (
 	lvmExtentSize   map[string]int64
 	lvmExtentSizeMu sync.Mutex
@@ -170,8 +172,8 @@ func (d *lvm) Create() error {
 	var pvName string
 	var vgTags []string
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	err = d.FillConfig()
 	if err != nil {
@@ -216,7 +218,7 @@ func (d *lvm) Create() error {
 			return fmt.Errorf("Failed to create sparse file %q: %w", d.config["source"], err)
 		}
 
-		revert.Add(func() { _ = os.Remove(d.config["source"]) })
+		reverter.Add(func() { _ = os.Remove(d.config["source"]) })
 
 		// Open the loop file.
 		loopDevPath, err := d.openLoopFile(d.config["source"])
@@ -252,7 +254,7 @@ func (d *lvm) Create() error {
 
 		// Size is invalid as the physical device is already sized.
 		if d.config["size"] != "" && !d.usesThinpool() {
-			return fmt.Errorf("Cannot specify size when using an existing physical device for non-thin pool")
+			return errors.New("Cannot specify size when using an existing physical device for non-thin pool")
 		}
 
 		if d.config["lvm.vg_name"] == "" {
@@ -262,7 +264,7 @@ func (d *lvm) Create() error {
 		d.config["source"] = d.config["lvm.vg_name"]
 
 		if !linux.IsBlockdevPath(srcPath) {
-			return fmt.Errorf("Custom loop file locations are not supported")
+			return errors.New("Custom loop file locations are not supported")
 		}
 
 		// Wipe if requested.
@@ -297,11 +299,11 @@ func (d *lvm) Create() error {
 
 		// Size is invalid as the volume group is already sized.
 		if d.config["size"] != "" && !d.usesThinpool() {
-			return fmt.Errorf("Cannot specify size when using an existing volume group for non-thin pool")
+			return errors.New("Cannot specify size when using an existing volume group for non-thin pool")
 		}
 
 		if d.config["lvm.vg_name"] != "" && d.config["lvm.vg_name"] != d.config["source"] {
-			return fmt.Errorf("Invalid combination of source and lvm.vg_name properties")
+			return errors.New("Invalid combination of source and lvm.vg_name properties")
 		}
 
 		d.config["lvm.vg_name"] = d.config["source"]
@@ -316,12 +318,12 @@ func (d *lvm) Create() error {
 			return fmt.Errorf("The requested volume group %q does not exist", d.config["lvm.vg_name"])
 		}
 	} else {
-		return fmt.Errorf("Invalid source property")
+		return errors.New("Invalid source property")
 	}
 
 	// This is an internal error condition which should never be hit.
 	if d.config["lvm.vg_name"] == "" {
-		return fmt.Errorf("No name for volume group detected")
+		return errors.New("No name for volume group detected")
 	}
 
 	// Used to track the result of checking whether the thin pool exists during the existing volume group empty
@@ -375,7 +377,7 @@ func (d *lvm) Create() error {
 		if !pvExists {
 			// This is an internal error condition which should never be hit.
 			if pvName == "" {
-				return fmt.Errorf("No name for physical volume detected")
+				return errors.New("No name for physical volume detected")
 			}
 
 			args := []string{}
@@ -396,7 +398,7 @@ func (d *lvm) Create() error {
 				return err
 			}
 
-			revert.Add(func() { _, _ = subprocess.TryRunCommand("pvremove", pvName) })
+			reverter.Add(func() { _, _ = subprocess.TryRunCommand("pvremove", pvName) })
 		}
 
 		// Create volume group.
@@ -412,7 +414,7 @@ func (d *lvm) Create() error {
 		}
 
 		d.logger.Debug("Volume group created", logger.Ctx{"pv_name": pvName, "vg_name": d.config["lvm.vg_name"]})
-		revert.Add(func() { _, _ = subprocess.TryRunCommand("vgremove", d.config["lvm.vg_name"]) })
+		reverter.Add(func() { _, _ = subprocess.TryRunCommand("vgremove", d.config["lvm.vg_name"]) })
 	}
 
 	// Create thin pool if needed.
@@ -435,11 +437,11 @@ func (d *lvm) Create() error {
 
 			d.logger.Debug("Thin pool created", logger.Ctx{"vg_name": d.config["lvm.vg_name"], "thinpool_name": d.thinpoolName()})
 
-			revert.Add(func() {
-				_ = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], "", "", d.thinpoolName()))
+			reverter.Add(func() {
+				_ = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], "", "", d.thinpoolName()))
 			})
 		} else if d.config["size"] != "" {
-			return fmt.Errorf("Cannot specify size when using an existing thin pool")
+			return errors.New("Cannot specify size when using an existing thin pool")
 		}
 	}
 
@@ -451,7 +453,7 @@ func (d *lvm) Create() error {
 
 	d.logger.Debug("Incus marker tag added to volume group", logger.Ctx{"vg_name": d.config["lvm.vg_name"]})
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -510,7 +512,7 @@ func (d *lvm) Delete(op *operations.Operation) error {
 					} else if thinVolCount == 0 && lvCount > 1 {
 						// Otherwise, if the thin pool is empty but the volume group has
 						// other volumes, then just remove the thin pool volume.
-						err = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], "", "", d.thinpoolName()))
+						err = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], "", "", d.thinpoolName()))
 						if err != nil {
 							return fmt.Errorf("Failed to delete thin pool %q from volume group %q: %w", d.thinpoolName(), d.config["lvm.vg_name"], err)
 						}
@@ -596,11 +598,11 @@ func (d *lvm) Validate(config map[string]string) error {
 
 	if util.IsFalse(config["lvm.use_thinpool"]) {
 		if config["lvm.thinpool_name"] != "" {
-			return fmt.Errorf("The key lvm.use_thinpool cannot be set to false when lvm.thinpool_name is set")
+			return errors.New("The key lvm.use_thinpool cannot be set to false when lvm.thinpool_name is set")
 		}
 
 		if config["lvm.thinpool_metadata_size"] != "" {
-			return fmt.Errorf("The key lvm.use_thinpool cannot be set to false when lvm.thinpool_metadata_size is set")
+			return errors.New("The key lvm.use_thinpool cannot be set to false when lvm.thinpool_metadata_size is set")
 		}
 	}
 
@@ -611,27 +613,27 @@ func (d *lvm) Validate(config map[string]string) error {
 func (d *lvm) Update(changedConfig map[string]string) error {
 	_, changed := changedConfig["lvm.use_thinpool"]
 	if changed {
-		return fmt.Errorf("lvm.use_thinpool cannot be changed")
+		return errors.New("lvm.use_thinpool cannot be changed")
 	}
 
 	_, changed = changedConfig["lvm.thinpool_metadata_size"]
 	if changed {
-		return fmt.Errorf("lvm.thinpool_metadata_size cannot be changed")
+		return errors.New("lvm.thinpool_metadata_size cannot be changed")
 	}
 
 	_, changed = changedConfig["lvm.metadata_size"]
 	if changed {
-		return fmt.Errorf("lvm.metadata_size cannot be changed")
+		return errors.New("lvm.metadata_size cannot be changed")
 	}
 
 	_, changed = changedConfig["volume.lvm.stripes"]
 	if changed && d.usesThinpool() {
-		return fmt.Errorf("volume.lvm.stripes cannot be changed when using thin pool")
+		return errors.New("volume.lvm.stripes cannot be changed when using thin pool")
 	}
 
 	_, changed = changedConfig["volume.lvm.stripes.size"]
 	if changed && d.usesThinpool() {
-		return fmt.Errorf("volume.lvm.stripes.size cannot be changed when using thin pool")
+		return errors.New("volume.lvm.stripes.size cannot be changed when using thin pool")
 	}
 
 	if changedConfig["lvm.vg_name"] != "" {
@@ -658,7 +660,7 @@ func (d *lvm) Update(changedConfig map[string]string) error {
 		loopPath := loopFilePath(d.name)
 
 		if d.config["source"] != loopPath {
-			return fmt.Errorf("Cannot resize non-loopback pools")
+			return errors.New("Cannot resize non-loopback pools")
 		}
 
 		// Resize loop file
@@ -693,7 +695,7 @@ func (d *lvm) Update(changedConfig map[string]string) error {
 		}
 
 		if d.usesThinpool() {
-			lvPath := d.lvmDevPath(d.config["lvm.vg_name"], "", "", d.thinpoolName())
+			lvPath := d.lvmPath(d.config["lvm.vg_name"], "", "", d.thinpoolName())
 
 			// Use the remaining space in the volume group.
 			_, err = subprocess.RunCommand("lvresize", "-f", "-l", "+100%FREE", lvPath)
@@ -719,8 +721,8 @@ func (d *lvm) Mount() (bool, error) {
 
 	waitDuration := time.Second * time.Duration(5)
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// If clustered LVM, start lock manager.
 	if d.clustered {
@@ -738,7 +740,7 @@ func (d *lvm) Mount() (bool, error) {
 			return false, err
 		}
 
-		revert.Add(func() { _ = loopDeviceAutoDetach(loopDevPath) })
+		reverter.Add(func() { _ = loopDeviceAutoDetach(loopDevPath) })
 
 		// Wait for volume group to be detected if wasn't detected before.
 		if !vgExists {
@@ -777,7 +779,7 @@ func (d *lvm) Mount() (bool, error) {
 		}
 	}
 
-	revert.Success()
+	reverter.Success()
 	return ourMount, nil
 }
 
@@ -801,7 +803,7 @@ func (d *lvm) GetResources() (*api.ResourcesStoragePool, error) {
 	// Thinpools will always report zero free space on the volume group, so calculate approx
 	// used space using the thinpool logical volume allocated (data and meta) percentages.
 	if d.usesThinpool() {
-		volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], "", "", d.thinpoolName())
+		volDevPath := d.lvmPath(d.config["lvm.vg_name"], "", "", d.thinpoolName())
 		totalSize, usedSize, err := d.thinPoolVolumeUsage(volDevPath)
 		if err != nil {
 			return nil, err
@@ -827,7 +829,7 @@ func (d *lvm) GetResources() (*api.ResourcesStoragePool, error) {
 
 		parts := strings.Split(strings.TrimSpace(out), ",")
 		if len(parts) < 2 {
-			return nil, fmt.Errorf("Unexpected output from vgs command")
+			return nil, errors.New("Unexpected output from vgs command")
 		}
 
 		total, err := strconv.ParseUint(parts[0], 10, 64)
