@@ -2,6 +2,7 @@ package drivers
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"net/http"
 	"os"
@@ -70,7 +71,7 @@ func (d *lvm) thinpoolName() string {
 // openLoopFile opens a loop device and returns the device path.
 func (d *lvm) openLoopFile(source string) (string, error) {
 	if source == "" {
-		return "", fmt.Errorf("No source property found for the storage pool")
+		return "", errors.New("No source property found for the storage pool")
 	}
 
 	if filepath.IsAbs(source) && !linux.IsBlockdevPath(source) {
@@ -89,19 +90,16 @@ func (d *lvm) openLoopFile(source string) (string, error) {
 		return loopDeviceName, nil
 	}
 
-	return "", fmt.Errorf("Source is not loop file")
+	return "", errors.New("Source is not loop file")
 }
 
 // isLVMNotFoundExitError checks whether the supplied error is an exit error from an LVM command
 // meaning that the object was not found. Returns true if it is (exit status 5) false if not.
 func (d *lvm) isLVMNotFoundExitError(err error) bool {
-	runErr, ok := err.(subprocess.RunError)
-	if ok {
-		exitError, ok := runErr.Unwrap().(*exec.ExitError)
-		if ok {
-			if exitError.ExitCode() == 5 {
-				return true
-			}
+	var exitError *exec.ExitError
+	if errors.As(err, &exitError) {
+		if exitError.ExitCode() == 5 {
+			return true
 		}
 	}
 
@@ -399,7 +397,11 @@ func (d *lvm) createLogicalVolume(vgName, thinPoolName string, vol Volume, makeT
 		return fmt.Errorf("Error creating LVM logical volume %q: %w", lvFullName, err)
 	}
 
-	volDevPath := d.lvmDevPath(vgName, vol.volType, vol.contentType, vol.name)
+	volPath := d.lvmPath(vgName, vol.volType, vol.contentType, vol.name)
+	volDevPath, err := d.lvmDevPath(volPath)
+	if err != nil {
+		return err
+	}
 
 	if vol.contentType == ContentTypeFS {
 		_, err = makeFSType(volDevPath, vol.ConfigBlockFilesystem(), nil)
@@ -422,9 +424,9 @@ func (d *lvm) createLogicalVolume(vgName, thinPoolName string, vol Volume, makeT
 	if isRecent {
 		// Disable auto activation of volume on LVM versions that support it.
 		// Must be done after volume create so that zeroing and signature wiping can take place.
-		_, err := subprocess.TryRunCommand("lvchange", "--setactivationskip", "y", volDevPath)
+		_, err := subprocess.TryRunCommand("lvchange", "--setactivationskip", "y", volPath)
 		if err != nil {
-			return fmt.Errorf("Failed to set activation skip on LVM logical volume %q: %w", volDevPath, err)
+			return fmt.Errorf("Failed to set activation skip on LVM logical volume %q: %w", volPath, err)
 		}
 	}
 
@@ -434,15 +436,15 @@ func (d *lvm) createLogicalVolume(vgName, thinPoolName string, vol Volume, makeT
 
 // createLogicalVolumeSnapshot creates a snapshot of a logical volume.
 func (d *lvm) createLogicalVolumeSnapshot(vgName string, srcVol Volume, snapVol Volume, readonly bool, makeThinLv bool) (string, error) {
-	srcVolDevPath := d.lvmDevPath(vgName, srcVol.volType, srcVol.contentType, srcVol.name)
+	srcVolPath := d.lvmPath(vgName, srcVol.volType, srcVol.contentType, srcVol.name)
 	isRecent, err := d.lvmVersionIsAtLeast(lvmVersion, "2.02.99")
 	if err != nil {
 		return "", fmt.Errorf("Error checking LVM version: %w", err)
 	}
 
 	snapLvName := d.lvmFullVolumeName(snapVol.volType, snapVol.contentType, snapVol.name)
-	logCtx := logger.Ctx{"vg_name": vgName, "lv_name": snapLvName, "src_dev": srcVolDevPath, "thin": makeThinLv}
-	args := []string{"-n", snapLvName, "-s", srcVolDevPath}
+	logCtx := logger.Ctx{"vg_name": vgName, "lv_name": snapLvName, "src_dev": srcVolPath, "thin": makeThinLv}
+	args := []string{"-n", snapLvName, "-s", srcVolPath}
 
 	if isRecent {
 		args = append(args, "--setactivationskip", "y")
@@ -461,8 +463,8 @@ func (d *lvm) createLogicalVolumeSnapshot(vgName string, srcVol Volume, snapVol
 		args = append(args, "-prw")
 	}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// If clustered, we need to acquire exclusive write access for this operation.
 	if d.clustered && !makeThinLv {
@@ -484,25 +486,35 @@ func (d *lvm) createLogicalVolumeSnapshot(vgName string, srcVol Volume, snapVol
 
 	d.logger.Debug("Logical volume snapshot created", logCtx)
 
-	revert.Add(func() {
-		_ = d.removeLogicalVolume(d.lvmDevPath(vgName, snapVol.volType, snapVol.contentType, snapVol.name))
+	reverter.Add(func() {
+		_ = d.removeLogicalVolume(d.lvmPath(vgName, snapVol.volType, snapVol.contentType, snapVol.name))
 	})
 
-	targetVolDevPath := d.lvmDevPath(vgName, snapVol.volType, snapVol.contentType, snapVol.name)
+	targetVolPath := d.lvmPath(vgName, snapVol.volType, snapVol.contentType, snapVol.name)
 
-	revert.Success()
-	return targetVolDevPath, nil
+	reverter.Success()
+	return targetVolPath, nil
 }
 
 // acquireExclusive switches a volume lock to exclusive mode.
 func (d *lvm) acquireExclusive(vol Volume) (func(), error) {
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
-
-	if !d.clustered || !util.PathExists(volDevPath) {
+	if !d.clustered {
 		return func() {}, nil
 	}
 
-	_, err := subprocess.TryRunCommand("lvchange", "--activate", "ey", "--ignoreactivationskip", volDevPath)
+	volDevPath, err := d.lvmDevPath(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name))
+	if err != nil {
+		if errors.Is(err, os.ErrNotExist) {
+			return func() {}, nil
+		}
+
+		return nil, err
+	}
+
+	lvmActivation.Lock()
+	defer lvmActivation.Unlock()
+
+	_, err = subprocess.TryRunCommand("lvchange", "--activate", "ey", "--ignoreactivationskip", volDevPath)
 	if err != nil {
 		return nil, fmt.Errorf("Failed to acquire exclusive lock on LVM logical volume %q: %w", volDevPath, err)
 	}
@@ -558,14 +570,44 @@ func (d *lvm) lvmFullVolumeName(volType VolumeType, contentType ContentType, vol
 	return fmt.Sprintf("%s_%s%s", volType, lvName, contentTypeSuffix)
 }
 
-// lvmDevPath returns the path to the LVM volume device. Empty string is returned if invalid volType supplied.
-func (d *lvm) lvmDevPath(vgName string, volType VolumeType, contentType ContentType, volName string) string {
+// lvmPath returns the VG/LV path suitable to pass to LVM commands.
+func (d *lvm) lvmPath(vgName string, volType VolumeType, contentType ContentType, volName string) string {
 	fullVolName := d.lvmFullVolumeName(volType, contentType, volName)
 	if fullVolName == "" {
 		return "" // Invalid volType supplied.
 	}
 
-	return fmt.Sprintf("/dev/%s/%s", vgName, fullVolName)
+	return fmt.Sprintf("%s/%s", vgName, fullVolName)
+}
+
+// lvmDevPath returns the /dev path for the LV.
+func (d *lvm) lvmDevPath(pathName string) (string, error) {
+	// Get the block dev.
+	output, err := subprocess.TryRunCommand("lvdisplay", "-c", pathName)
+	if err != nil {
+		return "", err
+	}
+
+	// Grab the major and minor.
+	fields := strings.Split(output, ":")
+
+	if len(fields) < 2 {
+		return "", errors.New("Bad lvdisplay output")
+	}
+
+	major := strings.TrimSpace(fields[len(fields)-2])
+	minor := strings.TrimSpace(fields[len(fields)-1])
+
+	if major == "-1" || minor == "-1" {
+		return "", os.ErrNotExist
+	}
+
+	target, err := os.Readlink(filepath.Join("/sys/dev/block", major+":"+minor))
+	if err != nil {
+		return "", err
+	}
+
+	return filepath.Join("/dev", filepath.Base(target)), nil
 }
 
 // resizeLogicalVolume resizes an LVM logical volume. This function does not resize any filesystem inside the LV.
@@ -591,8 +633,8 @@ func (d *lvm) resizeLogicalVolume(lvPath string, sizeBytes int64) error {
 
 // copyThinpoolVolume makes an optimised copy of a thinpool volume by using thinpool snapshots.
 func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refresh bool) error {
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	removeVols := []string{}
 
@@ -619,12 +661,12 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 			}
 
 			newSnapVolPath := newSnapVol.MountPath()
-			err = newSnapVol.EnsureMountPath()
+			err = newSnapVol.EnsureMountPath(false)
 			if err != nil {
 				return err
 			}
 
-			revert.Add(func() { _ = os.RemoveAll(newSnapVolPath) })
+			reverter.Add(func() { _ = os.RemoveAll(newSnapVolPath) })
 
 			// We do not modify the original snapshot so as to avoid damaging if it is corrupted for
 			// some reason. If the filesystem needs to have a unique UUID generated in order to mount
@@ -634,8 +676,8 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 				return fmt.Errorf("Error creating LVM logical volume snapshot: %w", err)
 			}
 
-			revert.Add(func() {
-				_ = d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], newSnapVol.volType, newSnapVol.contentType, newSnapVol.name))
+			reverter.Add(func() {
+				_ = d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], newSnapVol.volType, newSnapVol.contentType, newSnapVol.name))
 			})
 		}
 	}
@@ -648,12 +690,12 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 
 	if volExists {
 		if refresh {
-			newVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+			newVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 			tmpVolName := fmt.Sprintf("%s%s", vol.name, tmpVolSuffix)
-			tmpVolDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, tmpVolName)
+			tmpVolPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, tmpVolName)
 
 			// Rename existing volume to temporary new name so we can revert if needed.
-			err := d.renameLogicalVolume(newVolDevPath, tmpVolDevPath)
+			err := d.renameLogicalVolume(newVolPath, tmpVolPath)
 			if err != nil {
 				return fmt.Errorf("Error temporarily renaming original LVM logical volume: %w", err)
 			}
@@ -661,21 +703,21 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 			// Record this volume to be removed at the very end.
 			removeVols = append(removeVols, tmpVolName)
 
-			revert.Add(func() {
+			reverter.Add(func() {
 				// Rename the original volume back to the original name.
-				_ = d.renameLogicalVolume(tmpVolDevPath, newVolDevPath)
+				_ = d.renameLogicalVolume(tmpVolPath, newVolPath)
 			})
 		} else {
 			return fmt.Errorf("LVM volume already exists %q", vol.name)
 		}
 	} else {
 		volPath := vol.MountPath()
-		err := vol.EnsureMountPath()
+		err := vol.EnsureMountPath(false)
 		if err != nil {
 			return err
 		}
 
-		revert.Add(func() { _ = os.RemoveAll(volPath) })
+		reverter.Add(func() { _ = os.RemoveAll(volPath) })
 	}
 
 	// Create snapshot of source volume as new volume.
@@ -684,10 +726,10 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 		return fmt.Errorf("Error creating LVM logical volume snapshot: %w", err)
 	}
 
-	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+	volPath := d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 
-	revert.Add(func() {
-		_ = d.removeLogicalVolume(volDevPath)
+	reverter.Add(func() {
+		_ = d.removeLogicalVolume(volPath)
 	})
 
 	if vol.contentType == ContentTypeFS {
@@ -700,6 +742,11 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 				return err
 			}
 
+			volDevPath, err := d.lvmDevPath(volPath)
+			if err != nil {
+				return err
+			}
+
 			d.logger.Debug("Regenerating filesystem UUID", logger.Ctx{"dev": volDevPath, "fs": vol.ConfigBlockFilesystem()})
 			err = regenerateFilesystemUUID(vol.ConfigBlockFilesystem(), volDevPath)
 			if err != nil {
@@ -709,7 +756,7 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 
 		// Mount the volume and ensure the permissions are set correctly inside the mounted volume.
 		err = vol.MountTask(func(_ string, _ *operations.Operation) error {
-			return vol.EnsureMountPath()
+			return vol.EnsureMountPath(false)
 		}, nil)
 		if err != nil {
 			return err
@@ -725,13 +772,13 @@ func (d *lvm) copyThinpoolVolume(vol, srcVol Volume, srcSnapshots []Volume, refr
 
 	// Finally clean up original volumes left that were renamed with a tmpVolSuffix suffix.
 	for _, removeVolName := range removeVols {
-		err := d.removeLogicalVolume(d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, removeVolName))
+		err := d.removeLogicalVolume(d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, removeVolName))
 		if err != nil {
 			return fmt.Errorf("Error removing LVM volume %q: %w", vol.name, err)
 		}
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -767,7 +814,7 @@ func (d *lvm) thinPoolVolumeUsage(volDevPath string) (uint64, uint64, error) {
 
 	parts := util.SplitNTrimSpace(out, ",", -1, true)
 	if len(parts) < 2 {
-		return 0, 0, fmt.Errorf("Unexpected output from lvs command")
+		return 0, 0, errors.New("Unexpected output from lvs command")
 	}
 
 	total, err := strconv.ParseUint(parts[0], 10, 64)
@@ -829,48 +876,57 @@ func (d *lvm) parseLogicalVolumeSnapshot(parent Volume, lvmVolName string) strin
 
 // activateVolume activates an LVM logical volume if not already present. Returns true if activated, false if not.
 func (d *lvm) activateVolume(vol Volume) (bool, error) {
-	var volDevPath string
+	var volPath string
 
 	if d.usesThinpool() {
-		volDevPath = d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+		volPath = d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 	} else {
 		// Use parent for non-thinpool vols as activating the parent volume also activates its snapshots.
 		parent, _, _ := api.GetParentAndSnapshotName(vol.Name())
-		volDevPath = d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, parent)
+		volPath = d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, parent)
 	}
 
-	if !util.PathExists(volDevPath) {
-		if d.clustered {
-			_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volDevPath)
-			if err != nil {
-				return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volDevPath, err)
-			}
-		} else {
-			_, err := subprocess.RunCommand("lvchange", "--activate", "y", "--ignoreactivationskip", volDevPath)
-			if err != nil {
-				return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volDevPath, err)
-			}
+	_, err := d.lvmDevPath(volPath)
+	if err == nil {
+		// Already active.
+		return false, nil
+	}
+
+	if !errors.Is(err, os.ErrNotExist) {
+		// Actual failure.
+		return false, err
+	}
+
+	// Activate the volume.
+	lvmActivation.Lock()
+	defer lvmActivation.Unlock()
+
+	if d.clustered {
+		_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volPath)
+		if err != nil {
+			return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volPath, err)
+		}
+	} else {
+		_, err := subprocess.RunCommand("lvchange", "--activate", "y", "--ignoreactivationskip", volPath)
+		if err != nil {
+			return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volPath, err)
 		}
-
-		d.logger.Debug("Activated logical volume", logger.Ctx{"volName": vol.Name(), "dev": volDevPath})
-
-		return true, nil
 	}
 
-	return false, nil
+	d.logger.Debug("Activated logical volume", logger.Ctx{"volName": vol.Name(), "dev": volPath})
+
+	return true, nil
 }
 
 // deactivateVolume deactivates an LVM logical volume if present. Returns true if deactivated, false if not.
 func (d *lvm) deactivateVolume(vol Volume) (bool, error) {
-	var volDevPath string
+	var volPath string
 
 	if d.usesThinpool() {
-		volDevPath = d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+		volPath = d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
 	} else {
 		// Use parent for non-thinpool vols as deactivating the parent volume also activates its snapshots.
 		parent, _, _ := api.GetParentAndSnapshotName(vol.Name())
-		volDevPath = d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, parent)
-
 		if vol.IsSnapshot() {
 			parentVol := NewVolume(d, d.name, vol.volType, vol.contentType, parent, nil, d.config)
 
@@ -879,20 +935,32 @@ func (d *lvm) deactivateVolume(vol Volume) (bool, error) {
 				return false, nil
 			}
 		}
+
+		volPath = d.lvmPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, parent)
 	}
 
-	if util.PathExists(volDevPath) {
-		// Keep trying to deactivate a few times in case the device is still being flushed.
-		_, err := subprocess.TryRunCommand("lvchange", "--activate", "n", "--ignoreactivationskip", volDevPath)
-		if err != nil {
-			return false, fmt.Errorf("Failed to deactivate LVM logical volume %q: %w", volDevPath, err)
-		}
-
-		d.logger.Debug("Deactivated logical volume", logger.Ctx{"volName": vol.Name(), "dev": volDevPath})
-		return true, nil
+	_, err := d.lvmDevPath(volPath)
+	if errors.Is(err, os.ErrNotExist) {
+		// Already deactivated.
+		return false, nil
 	}
 
-	return false, nil
+	if err != nil {
+		// Actual failure.
+		return false, err
+	}
+
+	lvmActivation.Lock()
+	defer lvmActivation.Unlock()
+
+	// Keep trying to deactivate a few times in case the device is still being flushed.
+	_, err = subprocess.TryRunCommand("lvchange", "--activate", "n", "--ignoreactivationskip", volPath)
+	if err != nil {
+		return false, fmt.Errorf("Failed to deactivate LVM logical volume %q: %w", volPath, err)
+	}
+
+	d.logger.Debug("Deactivated logical volume", logger.Ctx{"volName": vol.Name(), "dev": volPath})
+	return true, nil
 }
 
 // getSourceType determines the source type based on the config["source"] value.
