@@ -10,6 +10,7 @@ import (
 	"slices"
 	"strconv"
 	"strings"
+	"sync"
 
 	"github.com/lxc/incus/v6/internal/linux"
 	"github.com/lxc/incus/v6/internal/migration"
@@ -57,6 +58,10 @@ var zfsDefaultSettings = map[string]string{
 
 type zfs struct {
 	common
+
+	// Temporary cache (typically lives for the duration of a query).
+	cache   map[string]map[string]int64
+	cacheMu sync.Mutex
 }
 
 // load is used to run one-time action per-driver rather than per-pool.
@@ -156,44 +161,107 @@ func (d *zfs) Info() Info {
 // ensureInitialDatasets creates missing initial datasets or configures existing ones with current policy.
 // Accepts warnOnExistingPolicyApplyError argument, if true will warn rather than fail if applying current policy
 // to an existing dataset fails.
-func (d zfs) ensureInitialDatasets(warnOnExistingPolicyApplyError bool) error {
-	args := make([]string, 0, len(zfsDefaultSettings))
+func (d *zfs) ensureInitialDatasets(warnOnExistingPolicyApplyError bool) error {
+	// Build the list of datasets to query.
+	datasets := []string{d.config["zfs.pool_name"]}
+	for _, entry := range d.initialDatasets() {
+		datasets = append(datasets, filepath.Join(d.config["zfs.pool_name"], entry))
+	}
+
+	// Build the list of properties to check.
+	props := []string{"name", "mountpoint", "volmode"}
+	for k := range zfsDefaultSettings {
+		props = append(props, k)
+	}
+
+	// Get current state.
+	args := append([]string{"get", "-H", "-p", "-o", "name,property,value", strings.Join(props, ",")}, datasets...)
+	output, _ := subprocess.RunCommand("zfs", args...)
+
+	currentConfig := map[string]map[string]string{}
+	for _, entry := range strings.Split(output, "\n") {
+		if entry == "" {
+			continue
+		}
+
+		fields := strings.Fields(entry)
+		if len(fields) != 3 {
+			continue
+		}
+
+		if currentConfig[fields[0]] == nil {
+			currentConfig[fields[0]] = map[string]string{}
+		}
+
+		currentConfig[fields[0]][fields[1]] = fields[2]
+	}
+
+	// Check that the root dataset is correctly configured.
+	args = []string{}
 	for k, v := range zfsDefaultSettings {
+		current := currentConfig[d.config["zfs.pool_name"]][k]
+		if current == v {
+			continue
+		}
+
+		// Workaround for values having been renamed over time.
+		if k == "acltype" && current == "posix" {
+			continue
+		}
+
+		if k == "xattr" && current == "on" {
+			continue
+		}
+
 		args = append(args, fmt.Sprintf("%s=%s", k, v))
 	}
 
-	err := d.setDatasetProperties(d.config["zfs.pool_name"], args...)
-	if err != nil {
-		if warnOnExistingPolicyApplyError {
+	if len(args) > 0 {
+		err := d.setDatasetProperties(d.config["zfs.pool_name"], args...)
+		if err != nil {
+			if !warnOnExistingPolicyApplyError {
+				return fmt.Errorf("Failed applying policy to existing dataset %q: %w", d.config["zfs.pool_name"], err)
+			}
+
 			d.logger.Warn("Failed applying policy to existing dataset", logger.Ctx{"dataset": d.config["zfs.pool_name"], "err": err})
-		} else {
-			return fmt.Errorf("Failed applying policy to existing dataset %q: %w", d.config["zfs.pool_name"], err)
 		}
 	}
 
+	// Check the initial datasets.
 	for _, dataset := range d.initialDatasets() {
-		properties := []string{"mountpoint=legacy"}
+		properties := map[string]string{"mountpoint": "legacy"}
 		if slices.Contains([]string{"virtual-machines", "deleted/virtual-machines"}, dataset) {
-			properties = append(properties, "volmode=none")
+			properties["volmode"] = "none"
 		}
 
 		datasetPath := filepath.Join(d.config["zfs.pool_name"], dataset)
-		exists, err := d.datasetExists(datasetPath)
-		if err != nil {
-			return err
-		}
+		if currentConfig[datasetPath] != nil {
+			args := []string{}
+			for k, v := range properties {
+				if currentConfig[datasetPath][k] == v {
+					continue
+				}
+
+				args = append(args, fmt.Sprintf("%s=%s", k, v))
+			}
+
+			if len(args) > 0 {
+				err := d.setDatasetProperties(datasetPath, args...)
+				if err != nil {
+					if !warnOnExistingPolicyApplyError {
+						return fmt.Errorf("Failed applying policy to existing dataset %q: %w", datasetPath, err)
+					}
 
-		if exists {
-			err = d.setDatasetProperties(datasetPath, properties...)
-			if err != nil {
-				if warnOnExistingPolicyApplyError {
 					d.logger.Warn("Failed applying policy to existing dataset", logger.Ctx{"dataset": datasetPath, "err": err})
-				} else {
-					return fmt.Errorf("Failed applying policy to existing dataset %q: %w", datasetPath, err)
 				}
 			}
 		} else {
-			err = d.createDataset(datasetPath, properties...)
+			args := []string{}
+			for k, v := range properties {
+				args = append(args, fmt.Sprintf("%s=%s", k, v))
+			}
+
+			err := d.createDataset(datasetPath, args...)
 			if err != nil {
 				return fmt.Errorf("Failed creating dataset %q: %w", datasetPath, err)
 			}
@@ -238,7 +306,7 @@ func (d *zfs) FillConfig() error {
 			d.config["size"] = fmt.Sprintf("%dGiB", defaultSize)
 		}
 	} else if sliceAny(devices, func(device string) bool { return !linux.IsBlockdevPath(device) }) {
-		return fmt.Errorf("Custom loop file locations are not supported")
+		return errors.New("Custom loop file locations are not supported")
 	} else {
 		// Set default pool_name.
 		if d.config["zfs.pool_name"] == "" {
@@ -268,7 +336,7 @@ func (d *zfs) Create() error {
 	if len(devices) == 1 && !filepath.IsAbs(devices[0]) {
 		// Validate pool_name.
 		if d.config["zfs.pool_name"] != devices[0] {
-			return fmt.Errorf("The source must match zfs.pool_name if specified")
+			return errors.New("The source must match zfs.pool_name if specified")
 		}
 
 		if strings.Contains(d.config["zfs.pool_name"], "/") {
@@ -304,7 +372,7 @@ func (d *zfs) Create() error {
 	} else if len(devices) == 1 && devices[0] == loopPath {
 		// Validate pool_name.
 		if strings.Contains(d.config["zfs.pool_name"], "/") {
-			return fmt.Errorf("zfs.pool_name can't point to a dataset when source isn't set")
+			return errors.New("zfs.pool_name can't point to a dataset when source isn't set")
 		}
 
 		// Create the loop file itself.
@@ -342,7 +410,7 @@ func (d *zfs) Create() error {
 		// At this moment, we have assurance from FillConfig that all devices are existing block devices
 		// Validate pool_name.
 		if strings.Contains(d.config["zfs.pool_name"], "/") {
-			return fmt.Errorf("zfs.pool_name can't point to a dataset when source isn't set")
+			return errors.New("zfs.pool_name can't point to a dataset when source isn't set")
 		}
 
 		var createArgs []string
@@ -386,10 +454,10 @@ func (d *zfs) Create() error {
 	}
 
 	// Setup revert in case of problems
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
-	revert.Add(func() { _ = d.Delete(nil) })
+	reverter.Add(func() { _ = d.Delete(nil) })
 
 	// Apply our default configuration.
 	err = d.ensureInitialDatasets(false)
@@ -397,7 +465,7 @@ func (d *zfs) Create() error {
 		return err
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -484,7 +552,7 @@ func (d *zfs) Validate(config map[string]string) error {
 func (d *zfs) Update(changedConfig map[string]string) error {
 	_, ok := changedConfig["zfs.pool_name"]
 	if ok {
-		return fmt.Errorf("zfs.pool_name cannot be modified")
+		return errors.New("zfs.pool_name cannot be modified")
 	}
 
 	size, ok := changedConfig["size"]
@@ -494,7 +562,7 @@ func (d *zfs) Update(changedConfig map[string]string) error {
 
 		_, devices := d.parseSource()
 		if len(devices) != 1 || devices[0] != loopPath {
-			return fmt.Errorf("Cannot resize non-loopback pools")
+			return errors.New("Cannot resize non-loopback pools")
 		}
 
 		// Resize loop file
@@ -545,7 +613,7 @@ func (d *zfs) importPool() (bool, error) {
 	}
 
 	if exists {
-		return false, fmt.Errorf("ZFS zpool exists but dataset is missing")
+		return false, errors.New("ZFS zpool exists but dataset is missing")
 	}
 
 	// Import the pool.
@@ -569,7 +637,7 @@ func (d *zfs) importPool() (bool, error) {
 	}
 
 	if !exists {
-		return false, fmt.Errorf("ZFS zpool exists but dataset is missing")
+		return false, errors.New("ZFS zpool exists but dataset is missing")
 	}
 
 	// We need to explicitly import the keys here so containers can start. This
