@@ -64,14 +64,22 @@ func genericVFSGetResources(d Driver) (*api.ResourcesStoragePool, error) {
 // genericVFSRenameVolume is a generic RenameVolume implementation for VFS-only drivers.
 func genericVFSRenameVolume(d Driver, vol Volume, newVolName string, op *operations.Operation) error {
 	if vol.IsSnapshot() {
-		return fmt.Errorf("Volume must not be a snapshot")
+		return errors.New("Volume must not be a snapshot")
 	}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
+
+	volName := vol.name
+
+	// Add a .iso suffix to ISO volumes.
+	if vol.volType == VolumeTypeCustom && vol.contentType == ContentTypeISO {
+		volName = volName + genericISOVolumeSuffix
+		newVolName = newVolName + genericISOVolumeSuffix
+	}
 
 	// Rename the volume itself.
-	srcVolumePath := GetVolumeMountPath(d.Name(), vol.volType, vol.name)
+	srcVolumePath := GetVolumeMountPath(d.Name(), vol.volType, volName)
 	dstVolumePath := GetVolumeMountPath(d.Name(), vol.volType, newVolName)
 
 	if util.PathExists(srcVolumePath) {
@@ -80,7 +88,7 @@ func genericVFSRenameVolume(d Driver, vol Volume, newVolName string, op *operati
 			return fmt.Errorf("Failed to rename %q to %q: %w", srcVolumePath, dstVolumePath, err)
 		}
 
-		revert.Add(func() { _ = os.Rename(dstVolumePath, srcVolumePath) })
+		reverter.Add(func() { _ = os.Rename(dstVolumePath, srcVolumePath) })
 	}
 
 	// And if present, the snapshots too.
@@ -93,10 +101,10 @@ func genericVFSRenameVolume(d Driver, vol Volume, newVolName string, op *operati
 			return fmt.Errorf("Failed to rename %q to %q: %w", srcSnapshotDir, dstSnapshotDir, err)
 		}
 
-		revert.Add(func() { _ = os.Rename(dstSnapshotDir, srcSnapshotDir) })
+		reverter.Add(func() { _ = os.Rename(dstSnapshotDir, srcSnapshotDir) })
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -134,7 +142,7 @@ func genericVFSVolumeSnapshots(d Driver, vol Volume, op *operations.Operation) (
 // genericVFSRenameVolumeSnapshot is a generic RenameVolumeSnapshot implementation for VFS-only drivers.
 func genericVFSRenameVolumeSnapshot(d Driver, snapVol Volume, newSnapshotName string, op *operations.Operation) error {
 	if !snapVol.IsSnapshot() {
-		return fmt.Errorf("Volume must be a snapshot")
+		return errors.New("Volume must be a snapshot")
 	}
 
 	parentName, _, _ := api.GetParentAndSnapshotName(snapVol.name)
@@ -295,8 +303,8 @@ func genericVFSCreateVolumeFromMigration(d Driver, initVolume func(vol Volume) (
 		return ErrNotSupported
 	}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Create the main volume if not refreshing.
 	if !volTargetArgs.Refresh {
@@ -305,7 +313,7 @@ func genericVFSCreateVolumeFromMigration(d Driver, initVolume func(vol Volume) (
 			return err
 		}
 
-		revert.Add(func() { _ = d.DeleteVolume(vol, op) })
+		reverter.Add(func() { _ = d.DeleteVolume(vol, op) })
 	}
 
 	recvFSVol := func(volName string, conn io.ReadWriteCloser, path string) error {
@@ -424,7 +432,7 @@ func genericVFSCreateVolumeFromMigration(d Driver, initVolume func(vol Volume) (
 			}
 
 			// Setup the revert.
-			revert.Add(func() {
+			reverter.Add(func() {
 				_ = d.DeleteVolumeSnapshot(snapVol, op)
 			})
 		}
@@ -456,7 +464,7 @@ func genericVFSCreateVolumeFromMigration(d Driver, initVolume func(vol Volume) (
 
 		// Run EnsureMountPath after mounting and syncing to ensure the mounted directory has the
 		// correct permissions set.
-		err = vol.EnsureMountPath()
+		err = vol.EnsureMountPath(false)
 		if err != nil {
 			return err
 		}
@@ -485,7 +493,7 @@ func genericVFSCreateVolumeFromMigration(d Driver, initVolume func(vol Volume) (
 		return err
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -854,8 +862,8 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 		return nil
 	}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Find the compression algorithm used for backup source data.
 	_, err := srcData.Seek(0, io.SeekStart)
@@ -874,7 +882,7 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 	}
 
 	if volExists {
-		return nil, nil, fmt.Errorf("Cannot restore volume, already exists on target")
+		return nil, nil, errors.New("Cannot restore volume, already exists on target")
 	}
 
 	// Create new empty volume.
@@ -883,7 +891,7 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 		return nil, nil, err
 	}
 
-	revert.Add(func() { _ = d.DeleteVolume(vol, op) })
+	reverter.Add(func() { _ = d.DeleteVolume(vol, op) })
 
 	if len(snapshots) > 0 {
 		// Create new snapshots directory.
@@ -920,7 +928,7 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 			return nil, nil, err
 		}
 
-		revert.Add(func() { _ = d.DeleteVolumeSnapshot(snapVol, op) })
+		reverter.Add(func() { _ = d.DeleteVolumeSnapshot(snapVol, op) })
 	}
 
 	err = d.MountVolume(vol, op)
@@ -928,7 +936,7 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 		return nil, nil, err
 	}
 
-	revert.Add(func() { _, _ = d.UnmountVolume(vol, false, op) })
+	reverter.Add(func() { _, _ = d.UnmountVolume(vol, false, op) })
 
 	backupPrefix := "backup/container"
 	if vol.IsVMBlock() {
@@ -945,13 +953,13 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 
 	// Run EnsureMountPath after mounting and unpacking to ensure the mounted directory has the
 	// correct permissions set.
-	err = vol.EnsureMountPath()
+	err = vol.EnsureMountPath(false)
 	if err != nil {
 		return nil, nil, err
 	}
 
-	cleanup := revert.Clone().Fail // Clone before calling revert.Success() so we can return the Fail func.
-	revert.Success()
+	cleanup := reverter.Clone().Fail // Clone before calling reverter.Success() so we can return the Fail func.
+	reverter.Success()
 
 	var postHook VolumePostHook
 	if vol.volType != VolumeTypeCustom {
@@ -981,7 +989,7 @@ func genericVFSBackupUnpack(d Driver, sysOS *sys.OS, vol Volume, snapshots []str
 // initVolume is run against the main volume (not the snapshots) and is often used for quota initialization.
 func genericVFSCopyVolume(d Driver, initVolume func(vol Volume) (revert.Hook, error), vol Volume, srcVol Volume, srcSnapshots []Volume, refresh bool, allowInconsistent bool, op *operations.Operation) error {
 	if vol.contentType != srcVol.contentType {
-		return fmt.Errorf("Content type of source and target must be the same")
+		return errors.New("Content type of source and target must be the same")
 	}
 
 	bwlimit := d.Config()["rsync.bwlimit"]
@@ -992,8 +1000,8 @@ func genericVFSCopyVolume(d Driver, initVolume func(vol Volume) (revert.Hook, er
 		rsyncArgs = append(rsyncArgs, "--exclude", genericVolumeDiskFile)
 	}
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Create the main volume if not refreshing.
 	if !refresh {
@@ -1002,7 +1010,7 @@ func genericVFSCopyVolume(d Driver, initVolume func(vol Volume) (revert.Hook, er
 			return err
 		}
 
-		revert.Add(func() { _ = d.DeleteVolume(vol, op) })
+		reverter.Add(func() { _ = d.DeleteVolume(vol, op) })
 	}
 
 	// Define function to send a filesystem volume.
@@ -1082,7 +1090,7 @@ func genericVFSCopyVolume(d Driver, initVolume func(vol Volume) (revert.Hook, er
 				}
 
 				// Setup the revert.
-				revert.Add(func() {
+				reverter.Add(func() {
 					_ = d.DeleteVolumeSnapshot(snapVol, op)
 				})
 			}
@@ -1120,7 +1128,7 @@ func genericVFSCopyVolume(d Driver, initVolume func(vol Volume) (revert.Hook, er
 
 		// Run EnsureMountPath after mounting and copying to ensure the mounted directory has the
 		// correct permissions set.
-		err = vol.EnsureMountPath()
+		err = vol.EnsureMountPath(false)
 		if err != nil {
 			return err
 		}
@@ -1131,7 +1139,7 @@ func genericVFSCopyVolume(d Driver, initVolume func(vol Volume) (revert.Hook, er
 		return err
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
