@@ -41,6 +41,11 @@ type Resources struct {
 	//
 	// API extension: resources_system
 	System ResourcesSystem `json:"system" yaml:"system"`
+
+	// Load average information
+	//
+	// API extension: resources_load
+	Load ResourcesLoad `json:"load" yaml:"load"`
 }
 
 // ResourcesCPU represents the cpu resources available on the system
@@ -98,6 +103,21 @@ type ResourcesCPUSocket struct {
 	// Maximum CPU frequency (Mhz)
 	// Example: 3500
 	FrequencyTurbo uint64 `json:"frequency_turbo,omitempty" yaml:"frequency_turbo,omitempty"`
+
+	// Address sizes
+	//
+	// API extension: resources_cpu_address_sizes.
+	AddressSizes *ResourcesCPUAddressSizes `json:"address_sizes,omitempty" yaml:"address_sizes,omitempty"`
+}
+
+// ResourcesCPUAddressSizes resprents address size information for a CPU socket.
+//
+// swagger:model
+//
+// API extension: resources_cpu_address_sizes.
+type ResourcesCPUAddressSizes struct {
+	PhysicalBits uint64 `json:"physical_bits" yaml:"physical_bits"`
+	VirtualBits  uint64 `json:"virtual_bits" yaml:"virtual_bits"`
 }
 
 // ResourcesCPUCache represents a CPU cache
@@ -141,6 +161,12 @@ type ResourcesCPUCore struct {
 	// Current frequency
 	// Example: 3500
 	Frequency uint64 `json:"frequency,omitempty" yaml:"frequency,omitempty"`
+
+	// List of CPU flags
+	// Example: []
+	//
+	// API extension: resources_cpu_flags
+	Flags []string `json:"flags" yaml:"flags"`
 }
 
 // ResourcesCPUThread represents a CPU thread on the system
@@ -556,7 +582,7 @@ type ResourcesNetworkCardSRIOV struct {
 	VFs []ResourcesNetworkCard `json:"vfs" yaml:"vfs"`
 }
 
-// ResourceNetworkCardVDPA represents the VDPA configuration of the network card
+// ResourcesNetworkCardVDPA represents the VDPA configuration of the network card
 //
 // swagger:model
 //
@@ -773,7 +799,7 @@ type ResourcesStoragePool struct {
 	// Disk space usage
 	Space ResourcesStoragePoolSpace `json:"space,omitempty" yaml:"space,omitempty"`
 
-	// DIsk inode usage
+	// Disk inode usage
 	Inodes ResourcesStoragePoolInodes `json:"inodes,omitempty" yaml:"inodes,omitempty"`
 }
 
@@ -1092,3 +1118,26 @@ type ResourcesSystemMotherboard struct {
 	// Example: None
 	Version string `json:"version" yaml:"version"`
 }
+
+// ResourcesLoad represents system load information
+//
+// swagger:model
+//
+// API extension: resources_load.
+type ResourcesLoad struct {
+	// Load average in the past minute
+	// Example: 0.69
+	Average1Min float64
+
+	// Load average in the past 5 minutes
+	// Example: 1.10
+	Average5Min float64
+
+	// Load average in the past 10 minutes
+	// Example: 1.29
+	Average10Min float64
+
+	// The number of active processes
+	// Example: 1234
+	Processes int
+}
