@@ -1,8 +1,8 @@
 package cliconfig
 
 import (
-	"fmt"
+	"errors"
 )
 
 // ErrNotLinux is returned when attempting to access the "local" remote on non-Linux systems.
-var ErrNotLinux = fmt.Errorf("Can't connect to a local server on a non-Linux system")
+var ErrNotLinux = errors.New("Can't connect to a local server on a non-Linux system")
