@@ -10,6 +10,13 @@ func IsTrue(value string) bool {
 	return slices.Contains([]string{"true", "1", "yes", "on"}, strings.ToLower(value))
 }
 
+// IsNeitherFalseNorEmpty is true, if value is neither false nor empty,
+// which is the contrary to IsFalseOrEmpty.
+func IsNeitherFalseNorEmpty(value string) bool {
+	isFalseOrEmtpy := IsFalseOrEmpty(value)
+	return !isFalseOrEmtpy
+}
+
 // IsTrueOrEmpty returns true if value is empty or if IsTrue() returns true.
 func IsTrueOrEmpty(value string) bool {
 	return value == "" || IsTrue(value)
@@ -24,3 +31,8 @@ func IsFalse(value string) bool {
 func IsFalseOrEmpty(value string) bool {
 	return value == "" || IsFalse(value)
 }
+
+// IsNoneOrEmpty returns true if value is empty or a "none" value.
+func IsNoneOrEmpty(value string) bool {
+	return value == "" || value == "none"
+}
